# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: APIRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import enterprise_pb2 as enterprise__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x41PIRequest.proto\x12\x0e\x41uthentication\x1a\x10\x65nterprise.proto\"\xb0\x01\n\nApiRequest\x12 \n\x18\x65ncryptedTransmissionKey\x18\x01 \x01(\x0c\x12\x13\n\x0bpublicKeyId\x18\x02 \x01(\x05\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x18\n\x10\x65ncryptedPayload\x18\x04 \x01(\x0c\x12\x16\n\x0e\x65ncryptionType\x18\x05 \x01(\x05\x12\x11\n\trecaptcha\x18\x06 \x01(\t\x12\x16\n\x0esubEnvironment\x18\x07 \x01(\t\"j\n\x11\x41piRequestPayload\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x02 \x01(\x0c\x12\x11\n\ttimeToken\x18\x03 \x01(\x0c\x12\x12\n\napiVersion\x18\x04 \x01(\x05\"6\n\tTransform\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x02 \x01(\x0c\":\n\rDeviceRequest\x12\x15\n\rclientVersion\x18\x01 \x01(\t\x12\x12\n\ndeviceName\x18\x02 \x01(\t\"T\n\x0b\x41uthRequest\x12\x15\n\rclientVersion\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x03 \x01(\x0c\"\x8b\x01\n\x14NewUserMinimumParams\x12\x19\n\x11minimumIterations\x18\x01 \x01(\x05\x12\x1a\n\x12passwordMatchRegex\x18\x02 \x03(\t\x12 \n\x18passwordMatchDescription\x18\x03 \x03(\t\x12\x1a\n\x12isEnterpriseDomain\x18\x04 \x01(\x08\"\x89\x01\n\x0fPreLoginRequest\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12,\n\tloginType\x18\x02 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x16\n\x0etwoFactorToken\x18\x03 \x01(\x0c\"\x80\x02\n\x0cLoginRequest\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12,\n\tloginType\x18\x02 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x1f\n\x17\x61uthenticationHashPrime\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x04 \x01(\x0c\x12\x14\n\x0c\x61uthResponse\x18\x05 \x01(\x0c\x12\x16\n\x0emcEnterpriseId\x18\x06 \x01(\x05\x12\x12\n\npush_token\x18\x07 \x01(\t\x12\x10\n\x08platform\x18\x08 \x01(\t\"\\\n\x0e\x44\x65viceResponse\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12,\n\x06status\x18\x02 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\"V\n\x04Salt\x12\x12\n\niterations\x18\x01 \x01(\x05\x12\x0c\n\x04salt\x18\x02 \x01(\x0c\x12\x11\n\talgorithm\x18\x03 \x01(\x05\x12\x0b\n\x03uid\x18\x04 \x01(\x0c\x12\x0c\n\x04name\x18\x05 \x01(\t\" \n\x10TwoFactorChannel\x12\x0c\n\x04type\x18\x01 \x01(\x05\"\xe2\x02\n\x11StartLoginRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x15\n\rclientVersion\x18\x03 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x04 \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x05 \x01(\x0c\x12,\n\tloginType\x18\x06 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x16\n\x0emcEnterpriseId\x18\x07 \x01(\x05\x12\x30\n\x0bloginMethod\x18\x08 \x01(\x0e\x32\x1b.Authentication.LoginMethod\x12\x15\n\rforceNewLogin\x18\t \x01(\x08\x12\x11\n\tcloneCode\x18\n \x01(\x0c\x12\x18\n\x10v2TwoFactorToken\x18\x0b \x01(\t\x12\x12\n\naccountUid\x18\x0c \x01(\x0c\"\x85\x04\n\rLoginResponse\x12.\n\nloginState\x18\x01 \x01(\x0e\x32\x1a.Authentication.LoginState\x12\x12\n\naccountUid\x18\x02 \x01(\x0c\x12\x17\n\x0fprimaryUsername\x18\x03 \x01(\t\x12\x18\n\x10\x65ncryptedDataKey\x18\x04 \x01(\x0c\x12\x42\n\x14\x65ncryptedDataKeyType\x18\x05 \x01(\x0e\x32$.Authentication.EncryptedDataKeyType\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x06 \x01(\x0c\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x07 \x01(\x0c\x12:\n\x10sessionTokenType\x18\x08 \x01(\x0e\x32 .Authentication.SessionTokenType\x12\x0f\n\x07message\x18\t \x01(\t\x12\x0b\n\x03url\x18\n \x01(\t\x12\x36\n\x08\x63hannels\x18\x0b \x03(\x0b\x32$.Authentication.TwoFactorChannelInfo\x12\"\n\x04salt\x18\x0c \x03(\x0b\x32\x14.Authentication.Salt\x12\x11\n\tcloneCode\x18\r \x01(\x0c\x12\x1a\n\x12stateSpecificValue\x18\x0e \x01(\t\x12\x18\n\x10ssoClientVersion\x18\x0f \x01(\t\"\x8c\x01\n\x0bSsoUserInfo\x12\x13\n\x0b\x63ompanyName\x18\x01 \x01(\t\x12\x13\n\x0bsamlRequest\x18\x02 \x01(\t\x12\x17\n\x0fsamlRequestType\x18\x03 \x01(\t\x12\x15\n\rssoDomainName\x18\x04 \x01(\t\x12\x10\n\x08loginUrl\x18\x05 \x01(\t\x12\x11\n\tlogoutUrl\x18\x06 \x01(\t\"\xd6\x01\n\x10PreLoginResponse\x12\x32\n\x0c\x64\x65viceStatus\x18\x01 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\x12\"\n\x04salt\x18\x02 \x03(\x0b\x32\x14.Authentication.Salt\x12\x38\n\x0eOBSOLETE_FIELD\x18\x03 \x03(\x0b\x32 .Authentication.TwoFactorChannel\x12\x30\n\x0bssoUserInfo\x18\x04 \x01(\x0b\x32\x1b.Authentication.SsoUserInfo\"&\n\x12LoginAsUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"W\n\x13LoginAsUserResponse\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x01 \x01(\x0c\x12!\n\x19\x65ncryptedSharedAccountKey\x18\x02 \x01(\x0c\"\x84\x01\n\x17ValidateAuthHashRequest\x12\x36\n\x0epasswordMethod\x18\x01 \x01(\x0e\x32\x1e.Authentication.PasswordMethod\x12\x14\n\x0c\x61uthResponse\x18\x02 \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x03 \x01(\x0c\"\x88\x02\n\x14TwoFactorChannelInfo\x12\x39\n\x0b\x63hannelType\x18\x01 \x01(\x0e\x32$.Authentication.TwoFactorChannelType\x12\x13\n\x0b\x63hannel_uid\x18\x02 \x01(\x0c\x12\x13\n\x0b\x63hannelName\x18\x03 \x01(\t\x12\x11\n\tchallenge\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x05 \x03(\t\x12\x13\n\x0bphoneNumber\x18\x06 \x01(\t\x12:\n\rmaxExpiration\x18\x07 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\x12\x11\n\tcreatedOn\x18\x08 \x01(\x03\"d\n\x12TwoFactorDuoStatus\x12\x14\n\x0c\x63\x61pabilities\x18\x01 \x03(\t\x12\x13\n\x0bphoneNumber\x18\x02 \x01(\t\x12\x12\n\nenroll_url\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"\xc7\x01\n\x13TwoFactorAddRequest\x12\x39\n\x0b\x63hannelType\x18\x01 \x01(\x0e\x32$.Authentication.TwoFactorChannelType\x12\x13\n\x0b\x63hannel_uid\x18\x02 \x01(\x0c\x12\x13\n\x0b\x63hannelName\x18\x03 \x01(\t\x12\x13\n\x0bphoneNumber\x18\x04 \x01(\t\x12\x36\n\x0b\x64uoPushType\x18\x05 \x01(\x0e\x32!.Authentication.TwoFactorPushType\"B\n\x16TwoFactorRenameRequest\x12\x13\n\x0b\x63hannel_uid\x18\x01 \x01(\x0c\x12\x13\n\x0b\x63hannelName\x18\x02 \x01(\t\"=\n\x14TwoFactorAddResponse\x12\x11\n\tchallenge\x18\x01 \x01(\t\x12\x12\n\nbackupKeys\x18\x02 \x03(\t\"-\n\x16TwoFactorDeleteRequest\x12\x13\n\x0b\x63hannel_uid\x18\x01 \x01(\x0c\"a\n\x15TwoFactorListResponse\x12\x36\n\x08\x63hannels\x18\x01 \x03(\x0b\x32$.Authentication.TwoFactorChannelInfo\x12\x10\n\x08\x65xpireOn\x18\x02 \x01(\x03\"Y\n TwoFactorUpdateExpirationRequest\x12\x35\n\x08\x65xpireIn\x18\x01 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\"\xc9\x01\n\x18TwoFactorValidateRequest\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x35\n\tvalueType\x18\x02 \x01(\x0e\x32\".Authentication.TwoFactorValueType\x12\r\n\x05value\x18\x03 \x01(\t\x12\x13\n\x0b\x63hannel_uid\x18\x04 \x01(\x0c\x12\x35\n\x08\x65xpireIn\x18\x05 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\"8\n\x19TwoFactorValidateResponse\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\"\xb8\x01\n\x18TwoFactorSendPushRequest\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x33\n\x08pushType\x18\x02 \x01(\x0e\x32!.Authentication.TwoFactorPushType\x12\x13\n\x0b\x63hannel_uid\x18\x03 \x01(\x0c\x12\x35\n\x08\x65xpireIn\x18\x04 \x01(\x0e\x32#.Authentication.TwoFactorExpiration\"\x83\x01\n\x07License\x12\x0f\n\x07\x63reated\x18\x01 \x01(\x03\x12\x12\n\nexpiration\x18\x02 \x01(\x03\x12\x34\n\rlicenseStatus\x18\x03 \x01(\x0e\x32\x1d.Authentication.LicenseStatus\x12\x0c\n\x04paid\x18\x04 \x01(\x08\x12\x0f\n\x07message\x18\x05 \x01(\t\"G\n\x0fOwnerlessRecord\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x11\n\trecordKey\x18\x02 \x01(\x0c\x12\x0e\n\x06status\x18\x03 \x01(\x05\"L\n\x10OwnerlessRecords\x12\x38\n\x0fownerlessRecord\x18\x01 \x03(\x0b\x32\x1f.Authentication.OwnerlessRecord\"\xd7\x01\n\x0fUserAuthRequest\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04salt\x18\x02 \x01(\x0c\x12\x12\n\niterations\x18\x03 \x01(\x05\x12\x1a\n\x12\x65ncryptedClientKey\x18\x04 \x01(\x0c\x12\x10\n\x08\x61uthHash\x18\x05 \x01(\x0c\x12\x18\n\x10\x65ncryptedDataKey\x18\x06 \x01(\x0c\x12,\n\tloginType\x18\x07 \x01(\x0e\x32\x19.Authentication.LoginType\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x11\n\talgorithm\x18\t \x01(\x05\"\x19\n\nUidRequest\x12\x0b\n\x03uid\x18\x01 \x03(\x0c\"\xab\x01\n\x13\x44\x65viceUpdateRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x12\n\ndeviceName\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65vicePublicKey\x18\x04 \x01(\x0c\x12\x32\n\x0c\x64\x65viceStatus\x18\x05 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\"\x81\x01\n\x1dRegisterDeviceInRegionRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x12\n\ndeviceName\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65vicePublicKey\x18\x04 \x01(\x0c\"\xf8\x02\n\x13RegistrationRequest\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12\x38\n\x0fuserAuthRequest\x18\x02 \x01(\x0b\x32\x1f.Authentication.UserAuthRequest\x12\x1a\n\x12\x65ncryptedClientKey\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x04 \x01(\x0c\x12\x11\n\tpublicKey\x18\x05 \x01(\x0c\x12\x18\n\x10verificationCode\x18\x06 \x01(\t\x12\x1e\n\x16\x64\x65precatedAuthHashHash\x18\x07 \x01(\x0c\x12$\n\x1c\x64\x65precatedEncryptedClientKey\x18\x08 \x01(\x0c\x12%\n\x1d\x64\x65precatedEncryptedPrivateKey\x18\t \x01(\x0c\x12\"\n\x1a\x64\x65precatedEncryptionParams\x18\n \x01(\x0c\"\xd0\x01\n\x16\x43onvertUserToV3Request\x12\x30\n\x0b\x61uthRequest\x18\x01 \x01(\x0b\x32\x1b.Authentication.AuthRequest\x12\x38\n\x0fuserAuthRequest\x18\x02 \x01(\x0b\x32\x1f.Authentication.UserAuthRequest\x12\x1a\n\x12\x65ncryptedClientKey\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x04 \x01(\x0c\x12\x11\n\tpublicKey\x18\x05 \x01(\x0c\"$\n\x10RevisionResponse\x12\x10\n\x08revision\x18\x01 \x01(\x03\"&\n\x12\x43hangeEmailRequest\x12\x10\n\x08newEmail\x18\x01 \x01(\t\"8\n\x13\x43hangeEmailResponse\x12!\n\x19\x65ncryptedChangeEmailToken\x18\x01 \x01(\x0c\"6\n\x1d\x45mailVerificationLinkResponse\x12\x15\n\remailVerified\x18\x01 \x01(\x08\")\n\x0cSecurityData\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x91\x01\n\x13SecurityDataRequest\x12\x38\n\x12recordSecurityData\x18\x01 \x03(\x0b\x32\x1c.Authentication.SecurityData\x12@\n\x1amasterPasswordSecurityData\x18\x02 \x03(\x0b\x32\x1c.Authentication.SecurityData\"\xb5\x01\n\x1dSecurityReportIncrementalData\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1b\n\x13\x63urrentSecurityData\x18\x02 \x01(\x0c\x12#\n\x1b\x63urrentSecurityDataRevision\x18\x03 \x01(\x03\x12\x17\n\x0foldSecurityData\x18\x04 \x01(\x0c\x12\x1f\n\x17oldSecurityDataRevision\x18\x05 \x01(\x03\"\x85\x02\n\x0eSecurityReport\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1b\n\x13\x65ncryptedReportData\x18\x02 \x01(\x0c\x12\x10\n\x08revision\x18\x03 \x01(\x03\x12\x11\n\ttwoFactor\x18\x04 \x01(\t\x12\x11\n\tlastLogin\x18\x05 \x01(\x03\x12\x1e\n\x16numberOfReusedPassword\x18\x06 \x01(\x05\x12T\n\x1dsecurityReportIncrementalData\x18\x07 \x03(\x0b\x32-.Authentication.SecurityReportIncrementalData\x12\x0e\n\x06userId\x18\x08 \x01(\x05\"S\n\x19SecurityReportSaveRequest\x12\x36\n\x0esecurityReport\x18\x01 \x03(\x0b\x32\x1e.Authentication.SecurityReport\")\n\x15SecurityReportRequest\x12\x10\n\x08\x66romPage\x18\x01 \x01(\x03\"\xb8\x01\n\x16SecurityReportResponse\x12\x1c\n\x14\x65nterprisePrivateKey\x18\x01 \x01(\x0c\x12\x36\n\x0esecurityReport\x18\x02 \x03(\x0b\x32\x1e.Authentication.SecurityReport\x12\x14\n\x0c\x61sOfRevision\x18\x03 \x01(\x03\x12\x10\n\x08\x66romPage\x18\x04 \x01(\x03\x12\x0e\n\x06toPage\x18\x05 \x01(\x03\x12\x10\n\x08\x63omplete\x18\x06 \x01(\x08\"\'\n\x16ReusedPasswordsRequest\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\">\n\x14SummaryConsoleReport\x12\x12\n\nreportType\x18\x01 \x01(\x05\x12\x12\n\nreportData\x18\x02 \x01(\x0c\"|\n\x12\x43hangeToKeyTypeOne\x12/\n\nobjectType\x18\x01 \x01(\x0e\x32\x1b.Authentication.ObjectTypes\x12\x12\n\nprimaryUid\x18\x02 \x01(\x0c\x12\x14\n\x0csecondaryUid\x18\x03 \x01(\x0c\x12\x0b\n\x03key\x18\x04 \x01(\x0c\"[\n\x19\x43hangeToKeyTypeOneRequest\x12>\n\x12\x63hangeToKeyTypeOne\x18\x01 \x03(\x0b\x32\".Authentication.ChangeToKeyTypeOne\"U\n\x18\x43hangeToKeyTypeOneStatus\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\"h\n\x1a\x43hangeToKeyTypeOneResponse\x12J\n\x18\x63hangeToKeyTypeOneStatus\x18\x01 \x03(\x0b\x32(.Authentication.ChangeToKeyTypeOneStatus\"!\n\x06SetKey\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03key\x18\x02 \x01(\x0c\"5\n\rSetKeyRequest\x12$\n\x04keys\x18\x01 \x03(\x0b\x32\x16.Authentication.SetKey\"\xf2\x04\n\x11\x43reateUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x14\n\x0c\x61uthVerifier\x18\x02 \x01(\x0c\x12\x18\n\x10\x65ncryptionParams\x18\x03 \x01(\x0c\x12\x14\n\x0crsaPublicKey\x18\x04 \x01(\x0c\x12\x1e\n\x16rsaEncryptedPrivateKey\x18\x05 \x01(\x0c\x12\x14\n\x0c\x65\x63\x63PublicKey\x18\x06 \x01(\x0c\x12\x1e\n\x16\x65\x63\x63\x45ncryptedPrivateKey\x18\x07 \x01(\x0c\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x08 \x01(\x0c\x12\x1a\n\x12\x65ncryptedClientKey\x18\t \x01(\x0c\x12\x15\n\rclientVersion\x18\n \x01(\t\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x0b \x01(\x0c\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x0c \x01(\x0c\x12\x19\n\x11messageSessionUid\x18\r \x01(\x0c\x12\x17\n\x0finstallReferrer\x18\x0e \x01(\t\x12\x0e\n\x06mccMNC\x18\x0f \x01(\x05\x12\x0b\n\x03mfg\x18\x10 \x01(\t\x12\r\n\x05model\x18\x11 \x01(\t\x12\r\n\x05\x62rand\x18\x12 \x01(\t\x12\x0f\n\x07product\x18\x13 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x14 \x01(\t\x12\x0f\n\x07\x63\x61rrier\x18\x15 \x01(\t\x12\x18\n\x10verificationCode\x18\x16 \x01(\t\x12\x42\n\x16\x65nterpriseRegistration\x18\x17 \x01(\x0b\x32\".Enterprise.EnterpriseRegistration\x12\"\n\x1a\x65ncryptedVerificationToken\x18\x18 \x01(\x0c\"W\n!NodeEnforcementAddOrUpdateRequest\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\x12\x13\n\x0b\x65nforcement\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"C\n\x1cNodeEnforcementRemoveRequest\x12\x0e\n\x06nodeId\x18\x01 \x01(\x03\x12\x13\n\x0b\x65nforcement\x18\x02 \x01(\t\"\x9f\x01\n\x0f\x41piRequestByKey\x12\r\n\x05keyId\x18\x01 \x01(\x05\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x0e\n\x06locale\x18\x04 \x01(\t\x12<\n\x11supportedLanguage\x18\x05 \x01(\x0e\x32!.Authentication.SupportedLanguage\x12\x0c\n\x04type\x18\x06 \x01(\x05\"\x8e\x02\n\x15\x41piRequestByKAtoKAKey\x12\x1b\n\x13sourceRegionGroupId\x18\x01 \x01(\x05\x12 \n\x18\x64\x65stinationRegionGroupId\x18\x02 \x01(\x05\x12\x18\n\x10sourceRegionName\x18\x03 \x01(\t\x12\x1d\n\x15\x64\x65stinationRegionName\x18\x04 \x01(\t\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12\x10\n\x08username\x18\x06 \x01(\t\x12\x0e\n\x06locale\x18\x07 \x01(\t\x12<\n\x11supportedLanguage\x18\x08 \x01(\x0e\x32!.Authentication.SupportedLanguage\x12\x0c\n\x04type\x18\t \x01(\x05\".\n\x0fMemcacheRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06userId\x18\x02 \x01(\x05\".\n\x10MemcacheResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x1cMasterPasswordReentryRequest\x12\x16\n\x0epbkdf2Password\x18\x01 \x01(\t\x12?\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32/.Authentication.MasterPasswordReentryActionType\"_\n\x19\x44\x65viceRegistrationRequest\x12\x15\n\rclientVersion\x18\x01 \x01(\t\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65vicePublicKey\x18\x03 \x01(\x0c\"\x9a\x01\n\x19\x44\x65viceVerificationRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x1b\n\x13verificationChannel\x18\x03 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x04 \x01(\x0c\x12\x15\n\rclientVersion\x18\x05 \x01(\t\"\xb2\x01\n\x1a\x44\x65viceVerificationResponse\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x03 \x01(\x0c\x12\x15\n\rclientVersion\x18\x04 \x01(\t\x12\x32\n\x0c\x64\x65viceStatus\x18\x05 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\"\xc8\x01\n\x15\x44\x65viceApprovalRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x18\n\x10twoFactorChannel\x18\x02 \x01(\t\x12\x15\n\rclientVersion\x18\x03 \x01(\t\x12\x0e\n\x06locale\x18\x04 \x01(\t\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x05 \x01(\x0c\x12\x10\n\x08totpCode\x18\x06 \x01(\t\x12\x10\n\x08\x64\x65viceIp\x18\x07 \x01(\t\x12\x1d\n\x15\x64\x65viceTokenExpireDays\x18\x08 \x01(\t\"9\n\x16\x44\x65viceApprovalResponse\x12\x1f\n\x17\x65ncryptedTwoFactorToken\x18\x01 \x01(\x0c\"~\n\x14\x41pproveDeviceRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x02 \x01(\x0c\x12\x14\n\x0c\x64\x65nyApproval\x18\x03 \x01(\x08\x12\x12\n\nlinkDevice\x18\x04 \x01(\x08\"E\n\x1a\x45nterpriseUserAliasRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\r\n\x05\x61lias\x18\x02 \x01(\t\"Y\n\x1d\x45nterpriseUserAddAliasRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\x08\"&\n\x06\x44\x65vice\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\"\\\n\x1cRegisterDeviceDataKeyRequest\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x01 \x01(\x0c\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x02 \x01(\x0c\"n\n)ValidateCreateUserVerificationCodeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x18\n\x10verificationCode\x18\x03 \x01(\t\"\xa3\x01\n%ValidateDeviceVerificationCodeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x18\n\x10verificationCode\x18\x03 \x01(\t\x12\x19\n\x11messageSessionUid\x18\x04 \x01(\x0c\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x05 \x01(\x0c\"Y\n\x19SendSessionMessageRequest\x12\x19\n\x11messageSessionUid\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\"M\n\x11GlobalUserAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x12\n\naccountUid\x18\x02 \x01(\x0c\x12\x12\n\nregionName\x18\x03 \x01(\t\"7\n\x0f\x41\x63\x63ountUsername\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x12\n\ndateActive\x18\x02 \x01(\t\"P\n\x19SsoServiceProviderRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rclientVersion\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\"a\n\x1aSsoServiceProviderResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05spUrl\x18\x02 \x01(\t\x12\x0f\n\x07isCloud\x18\x03 \x01(\x08\x12\x15\n\rclientVersion\x18\x04 \x01(\t\"4\n\x12UserSettingRequest\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"f\n\rThrottleState\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.Authentication.ThrottleType\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\x08\"\xb5\x01\n\x0eThrottleState2\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x16\n\x0ekeyDescription\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x18\n\x10valueDescription\x18\x04 \x01(\t\x12\x12\n\nidentifier\x18\x05 \x01(\t\x12\x0e\n\x06locked\x18\x06 \x01(\x08\x12\x1a\n\x12includedInAllClear\x18\x07 \x01(\x08\x12\x15\n\rexpireSeconds\x18\x08 \x01(\x05\"\x97\x01\n\x11\x44\x65viceInformation\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\x03\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x15\n\rclientVersion\x18\x03 \x01(\t\x12\x11\n\tlastLogin\x18\x04 \x01(\x03\x12\x32\n\x0c\x64\x65viceStatus\x18\x05 \x01(\x0e\x32\x1c.Authentication.DeviceStatus\"*\n\x0bUserSetting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\".\n\x12UserDataKeyRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x03(\x03\"Q\n\x1b\x45nterpriseUserIdDataKeyPair\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x18\n\x10\x65ncryptedDataKey\x18\x02 \x01(\x0c\"\x95\x01\n\x0bUserDataKey\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x0f\n\x07roleKey\x18\x02 \x01(\x0c\x12\x12\n\nprivateKey\x18\x03 \x01(\t\x12Q\n\x1c\x65nterpriseUserIdDataKeyPairs\x18\x04 \x03(\x0b\x32+.Authentication.EnterpriseUserIdDataKeyPair\"z\n\x13UserDataKeyResponse\x12\x31\n\x0cuserDataKeys\x18\x01 \x03(\x0b\x32\x1b.Authentication.UserDataKey\x12\x14\n\x0c\x61\x63\x63\x65ssDenied\x18\x02 \x03(\x03\x12\x1a\n\x12noEncryptedDataKey\x18\x03 \x03(\x03\"H\n)MasterPasswordRecoveryVerificationRequest\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\"U\n\x1cGetSecurityQuestionV3Request\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x18\n\x10verificationCode\x18\x02 \x01(\t\"r\n\x1dGetSecurityQuestionV3Response\x12\x18\n\x10securityQuestion\x18\x01 \x01(\t\x12\x15\n\rbackupKeyDate\x18\x02 \x01(\x03\x12\x0c\n\x04salt\x18\x03 \x01(\x0c\x12\x12\n\niterations\x18\x04 \x01(\x05\"n\n\x19GetDataKeyBackupV3Request\x12\x1b\n\x13\x65ncryptedLoginToken\x18\x01 \x01(\x0c\x12\x18\n\x10verificationCode\x18\x02 \x01(\t\x12\x1a\n\x12securityAnswerHash\x18\x03 \x01(\x0c\"v\n\rPasswordRules\x12\x10\n\x08ruleType\x18\x01 \x01(\t\x12\r\n\x05match\x18\x02 \x01(\x08\x12\x0f\n\x07pattern\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07minimum\x18\x05 \x01(\x05\x12\r\n\x05value\x18\x06 \x01(\t\"\xa3\x02\n\x1aGetDataKeyBackupV3Response\x12\x15\n\rdataKeyBackup\x18\x01 \x01(\x0c\x12\x19\n\x11\x64\x61taKeyBackupDate\x18\x02 \x01(\x03\x12\x11\n\tpublicKey\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x04 \x01(\x0c\x12\x11\n\tclientKey\x18\x05 \x01(\x0c\x12\x1d\n\x15\x65ncryptedSessionToken\x18\x06 \x01(\x0c\x12\x34\n\rpasswordRules\x18\x07 \x03(\x0b\x32\x1d.Authentication.PasswordRules\x12\x1a\n\x12passwordRulesIntro\x18\x08 \x01(\t\x12\x1f\n\x17minimumPbkdf2Iterations\x18\t \x01(\x05\")\n\x14GetPublicKeysRequest\x12\x11\n\tusernames\x18\x01 \x03(\t\"r\n\x11PublicKeyResponse\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x11\n\tpublicKey\x18\x02 \x01(\x0c\x12\x14\n\x0cpublicEccKey\x18\x03 \x01(\x0c\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x11\n\terrorCode\x18\x05 \x01(\t\"P\n\x15GetPublicKeysResponse\x12\x37\n\x0ckeyResponses\x18\x01 \x03(\x0b\x32!.Authentication.PublicKeyResponse\"F\n\x14SetEccKeyPairRequest\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\x1b\n\x13\x65ncryptedPrivateKey\x18\x02 \x01(\x0c\"X\n\x13\x41\x64\x64\x41ppSharesRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12+\n\x06shares\x18\x02 \x03(\x0b\x32\x1b.Authentication.AppShareAdd\">\n\x16RemoveAppSharesRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x0e\n\x06shares\x18\x02 \x03(\x0c\"\x87\x01\n\x0b\x41ppShareAdd\x12\x11\n\tsecretUid\x18\x02 \x01(\x0c\x12\x37\n\tshareType\x18\x03 \x01(\x0e\x32$.Authentication.ApplicationShareType\x12\x1a\n\x12\x65ncryptedSecretKey\x18\x04 \x01(\x0c\x12\x10\n\x08\x65\x64itable\x18\x05 \x01(\x08\"{\n\x08\x41ppShare\x12\x11\n\tsecretUid\x18\x01 \x01(\x0c\x12\x37\n\tshareType\x18\x02 \x01(\x0e\x32$.Authentication.ApplicationShareType\x12\x10\n\x08\x65\x64itable\x18\x03 \x01(\x08\x12\x11\n\tcreatedOn\x18\x04 \x01(\x03\"\xd9\x01\n\x13\x41\x64\x64\x41ppClientRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x17\n\x0f\x65ncryptedAppKey\x18\x02 \x01(\x0c\x12\x10\n\x08\x63lientId\x18\x03 \x01(\x0c\x12\x0e\n\x06lockIp\x18\x04 \x01(\x08\x12\x1b\n\x13\x66irstAccessExpireOn\x18\x05 \x01(\x03\x12\x16\n\x0e\x61\x63\x63\x65ssExpireOn\x18\x06 \x01(\x03\x12\n\n\x02id\x18\x07 \x01(\t\x12\x30\n\rappClientType\x18\x08 \x01(\x0e\x32\x19.Enterprise.AppClientType\"@\n\x17RemoveAppClientsRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63lients\x18\x02 \x03(\x0c\"~\n\x17\x41\x64\x64\x45xternalShareRequest\x12\x11\n\trecordUid\x18\x01 \x01(\x0c\x12\x1a\n\x12\x65ncryptedRecordKey\x18\x02 \x01(\x0c\x12\x10\n\x08\x63lientId\x18\x03 \x01(\x0c\x12\x16\n\x0e\x61\x63\x63\x65ssExpireOn\x18\x04 \x01(\x03\x12\n\n\x02id\x18\x05 \x01(\t\"\x82\x02\n\tAppClient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x02 \x01(\x0c\x12\x11\n\tcreatedOn\x18\x03 \x01(\x03\x12\x13\n\x0b\x66irstAccess\x18\x04 \x01(\x03\x12\x12\n\nlastAccess\x18\x05 \x01(\x03\x12\x11\n\tpublicKey\x18\x06 \x01(\x0c\x12\x0e\n\x06lockIp\x18\x07 \x01(\x08\x12\x11\n\tipAddress\x18\x08 \x01(\t\x12\x1b\n\x13\x66irstAccessExpireOn\x18\t \x01(\x03\x12\x16\n\x0e\x61\x63\x63\x65ssExpireOn\x18\n \x01(\x03\x12\x30\n\rappClientType\x18\x0b \x01(\x0e\x32\x19.Enterprise.AppClientType\")\n\x11GetAppInfoRequest\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x03(\x0c\"\x8e\x01\n\x07\x41ppInfo\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12(\n\x06shares\x18\x02 \x03(\x0b\x32\x18.Authentication.AppShare\x12*\n\x07\x63lients\x18\x03 \x03(\x0b\x32\x19.Authentication.AppClient\x12\x17\n\x0fisExternalShare\x18\x04 \x01(\x08\">\n\x12GetAppInfoResponse\x12(\n\x07\x61ppInfo\x18\x01 \x03(\x0b\x32\x17.Authentication.AppInfo\"\xb2\x01\n\x12\x41pplicationSummary\x12\x14\n\x0c\x61ppRecordUid\x18\x01 \x01(\x0c\x12\x12\n\nlastAccess\x18\x02 \x01(\x03\x12\x14\n\x0crecordShares\x18\x03 \x01(\x05\x12\x14\n\x0c\x66olderShares\x18\x04 \x01(\x05\x12\x15\n\rfolderRecords\x18\x05 \x01(\x05\x12\x13\n\x0b\x63lientCount\x18\x06 \x01(\x05\x12\x1a\n\x12\x65xpiredClientCount\x18\x07 \x01(\x05\"`\n\x1eGetApplicationsSummaryResponse\x12>\n\x12\x61pplicationSummary\x18\x01 \x03(\x0b\x32\".Authentication.ApplicationSummary\"/\n\x1bGetVerificationTokenRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"B\n\x1cGetVerificationTokenResponse\x12\"\n\x1a\x65ncryptedVerificationToken\x18\x01 \x01(\x0c\"\'\n\x16SendShareInviteRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\xc5\x01\n\x18TimeLimitedAccessRequest\x12\x12\n\naccountUid\x18\x01 \x03(\x0c\x12\x0f\n\x07teamUid\x18\x02 \x03(\x0c\x12\x11\n\trecordUid\x18\x03 \x03(\x0c\x12\x17\n\x0fsharedObjectUid\x18\x04 \x01(\x0c\x12\x44\n\x15timeLimitedAccessType\x18\x05 \x01(\x0e\x32%.Authentication.TimeLimitedAccessType\x12\x12\n\nexpiration\x18\x06 \x01(\x03\"-\n\x19TimeLimitedAccessResponse\x12\x10\n\x08revision\x18\x01 \x01(\x03\"+\n\x16RequestDownloadRequest\x12\x11\n\tfileNames\x18\x01 \x03(\t\"g\n\x17RequestDownloadResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12+\n\tdownloads\x18\x03 \x03(\x0b\x32\x18.Authentication.Download\"D\n\x08\x44ownload\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x19\n\x11successStatusCode\x18\x03 \x01(\x05\"#\n\x11\x44\x65leteUserRequest\x12\x0e\n\x06reason\x18\x01 \x01(\t*\xb9\x02\n\x11SupportedLanguage\x12\x0b\n\x07\x45NGLISH\x10\x00\x12\n\n\x06\x41RABIC\x10\x01\x12\x0b\n\x07\x42RITISH\x10\x02\x12\x0b\n\x07\x43HINESE\x10\x03\x12\x15\n\x11\x43HINESE_HONG_KONG\x10\x04\x12\x12\n\x0e\x43HINESE_TAIWAN\x10\x05\x12\t\n\x05\x44UTCH\x10\x06\x12\n\n\x06\x46RENCH\x10\x07\x12\n\n\x06GERMAN\x10\x08\x12\t\n\x05GREEK\x10\t\x12\n\n\x06HEBREW\x10\n\x12\x0b\n\x07ITALIAN\x10\x0b\x12\x0c\n\x08JAPANESE\x10\x0c\x12\n\n\x06KOREAN\x10\r\x12\n\n\x06POLISH\x10\x0e\x12\x0e\n\nPORTUGUESE\x10\x0f\x12\x15\n\x11PORTUGUESE_BRAZIL\x10\x10\x12\x0c\n\x08ROMANIAN\x10\x11\x12\x0b\n\x07RUSSIAN\x10\x12\x12\n\n\x06SLOVAK\x10\x13\x12\x0b\n\x07SPANISH\x10\x14*Z\n\tLoginType\x12\n\n\x06NORMAL\x10\x00\x12\x07\n\x03SSO\x10\x01\x12\x07\n\x03\x42IO\x10\x02\x12\r\n\tALTERNATE\x10\x03\x12\x0b\n\x07OFFLINE\x10\x04\x12\x13\n\x0f\x46ORGOT_PASSWORD\x10\x05*q\n\x0c\x44\x65viceStatus\x12\x19\n\x15\x44\x45VICE_NEEDS_APPROVAL\x10\x00\x12\r\n\tDEVICE_OK\x10\x01\x12\x1b\n\x17\x44\x45VICE_DISABLED_BY_USER\x10\x02\x12\x1a\n\x16\x44\x45VICE_LOCKED_BY_ADMIN\x10\x03*A\n\rLicenseStatus\x12\t\n\x05OTHER\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03*7\n\x0b\x41\x63\x63ountType\x12\x0c\n\x08\x43ONSUMER\x10\x00\x12\n\n\x06\x46\x41MILY\x10\x01\x12\x0e\n\nENTERPRISE\x10\x02*\xcc\x01\n\x10SessionTokenType\x12\x12\n\x0eNO_RESTRICTION\x10\x00\x12\x14\n\x10\x41\x43\x43OUNT_RECOVERY\x10\x01\x12\x11\n\rSHARE_ACCOUNT\x10\x02\x12\x0c\n\x08PURCHASE\x10\x03\x12\x0c\n\x08RESTRICT\x10\x04\x12\x11\n\rACCEPT_INVITE\x10\x05\x12\x12\n\x0eSUPPORT_SERVER\x10\x06\x12\x17\n\x13\x45NTERPRISE_CREATION\x10\x07\x12\x1f\n\x1b\x45XPIRED_BUT_ALLOWED_TO_SYNC\x10\x08*G\n\x07Version\x12\x13\n\x0finvalid_version\x10\x00\x12\x13\n\x0f\x64\x65\x66\x61ult_version\x10\x01\x12\x12\n\x0esecond_version\x10\x02*7\n\x1fMasterPasswordReentryActionType\x12\n\n\x06UNMASK\x10\x00\x12\x08\n\x04\x43OPY\x10\x01*l\n\x0bLoginMethod\x12\x17\n\x13INVALID_LOGINMETHOD\x10\x00\x12\x14\n\x10\x45XISTING_ACCOUNT\x10\x01\x12\x0e\n\nSSO_DOMAIN\x10\x02\x12\r\n\tAFTER_SSO\x10\x03\x12\x0f\n\x0bNEW_ACCOUNT\x10\x04*\xc7\x03\n\nLoginState\x12\x16\n\x12INVALID_LOGINSTATE\x10\x00\x12\x0e\n\nLOGGED_OUT\x10\x01\x12\x1c\n\x18\x44\x45VICE_APPROVAL_REQUIRED\x10\x02\x12\x11\n\rDEVICE_LOCKED\x10\x03\x12\x12\n\x0e\x41\x43\x43OUNT_LOCKED\x10\x04\x12\x19\n\x15\x44\x45VICE_ACCOUNT_LOCKED\x10\x05\x12\x0b\n\x07UPGRADE\x10\x06\x12\x13\n\x0fLICENSE_EXPIRED\x10\x07\x12\x13\n\x0fREGION_REDIRECT\x10\x08\x12\x16\n\x12REDIRECT_CLOUD_SSO\x10\t\x12\x17\n\x13REDIRECT_ONSITE_SSO\x10\n\x12\x10\n\x0cREQUIRES_2FA\x10\x0c\x12\x16\n\x12REQUIRES_AUTH_HASH\x10\r\x12\x15\n\x11REQUIRES_USERNAME\x10\x0e\x12\x19\n\x15\x41\x46TER_CLOUD_SSO_LOGIN\x10\x0f\x12\x1d\n\x19REQUIRES_ACCOUNT_CREATION\x10\x10\x12&\n\"REQUIRES_DEVICE_ENCRYPTED_DATA_KEY\x10\x11\x12\x17\n\x13LOGIN_TOKEN_EXPIRED\x10\x12\x12\r\n\tLOGGED_IN\x10\x63*k\n\x14\x45ncryptedDataKeyType\x12\n\n\x06NO_KEY\x10\x00\x12\x18\n\x14\x42Y_DEVICE_PUBLIC_KEY\x10\x01\x12\x0f\n\x0b\x42Y_PASSWORD\x10\x02\x12\x10\n\x0c\x42Y_ALTERNATE\x10\x03\x12\n\n\x06\x42Y_BIO\x10\x04*-\n\x0ePasswordMethod\x12\x0b\n\x07\x45NTERED\x10\x00\x12\x0e\n\nBIOMETRICS\x10\x01*\xb9\x01\n\x11TwoFactorPushType\x12\x14\n\x10TWO_FA_PUSH_NONE\x10\x00\x12\x13\n\x0fTWO_FA_PUSH_SMS\x10\x01\x12\x16\n\x12TWO_FA_PUSH_KEEPER\x10\x02\x12\x18\n\x14TWO_FA_PUSH_DUO_PUSH\x10\x03\x12\x18\n\x14TWO_FA_PUSH_DUO_TEXT\x10\x04\x12\x18\n\x14TWO_FA_PUSH_DUO_CALL\x10\x05\x12\x13\n\x0fTWO_FA_PUSH_DNA\x10\x06*\xc3\x01\n\x12TwoFactorValueType\x12\x14\n\x10TWO_FA_CODE_NONE\x10\x00\x12\x14\n\x10TWO_FA_CODE_TOTP\x10\x01\x12\x13\n\x0fTWO_FA_CODE_SMS\x10\x02\x12\x13\n\x0fTWO_FA_CODE_DUO\x10\x03\x12\x13\n\x0fTWO_FA_CODE_RSA\x10\x04\x12\x13\n\x0fTWO_FA_RESP_U2F\x10\x05\x12\x18\n\x14TWO_FA_RESP_WEBAUTHN\x10\x06\x12\x13\n\x0fTWO_FA_CODE_DNA\x10\x07*\xe1\x01\n\x14TwoFactorChannelType\x12\x12\n\x0eTWO_FA_CT_NONE\x10\x00\x12\x12\n\x0eTWO_FA_CT_TOTP\x10\x01\x12\x11\n\rTWO_FA_CT_SMS\x10\x02\x12\x11\n\rTWO_FA_CT_DUO\x10\x03\x12\x11\n\rTWO_FA_CT_RSA\x10\x04\x12\x14\n\x10TWO_FA_CT_BACKUP\x10\x05\x12\x11\n\rTWO_FA_CT_U2F\x10\x06\x12\x16\n\x12TWO_FA_CT_WEBAUTHN\x10\x07\x12\x14\n\x10TWO_FA_CT_KEEPER\x10\x08\x12\x11\n\rTWO_FA_CT_DNA\x10\t*\xab\x01\n\x13TwoFactorExpiration\x12\x1a\n\x16TWO_FA_EXP_IMMEDIATELY\x10\x00\x12\x18\n\x14TWO_FA_EXP_5_MINUTES\x10\x01\x12\x17\n\x13TWO_FA_EXP_12_HOURS\x10\x02\x12\x17\n\x13TWO_FA_EXP_24_HOURS\x10\x03\x12\x16\n\x12TWO_FA_EXP_30_DAYS\x10\x04\x12\x14\n\x10TWO_FA_EXP_NEVER\x10\x05*@\n\x0bLicenseType\x12\t\n\x05VAULT\x10\x00\x12\x08\n\x04\x43HAT\x10\x01\x12\x0b\n\x07STORAGE\x10\x02\x12\x0f\n\x0b\x42REACHWATCH\x10\x03*i\n\x0bObjectTypes\x12\n\n\x06RECORD\x10\x00\x12\x16\n\x12SHARED_FOLDER_USER\x10\x01\x12\x16\n\x12SHARED_FOLDER_TEAM\x10\x02\x12\x0f\n\x0bUSER_FOLDER\x10\x03\x12\r\n\tTEAM_USER\x10\x04*`\n\x1b\x41lternateAuthenticationType\x12\x1d\n\x19\x41LTERNATE_MASTER_PASSWORD\x10\x00\x12\r\n\tBIOMETRIC\x10\x01\x12\x13\n\x0f\x41\x43\x43OUNT_RECOVER\x10\x02*\x9a\x02\n\x0cThrottleType\x12\x1b\n\x17PASSWORD_RETRY_THROTTLE\x10\x00\x12\"\n\x1ePASSWORD_RETRY_LEGACY_THROTTLE\x10\x01\x12\x13\n\x0fTWO_FA_THROTTLE\x10\x02\x12\x1a\n\x16TWO_FA_LEGACY_THROTTLE\x10\x03\x12\x15\n\x11QA_RETRY_THROTTLE\x10\x04\x12\x1c\n\x18\x41\x43\x43OUNT_RECOVER_THROTTLE\x10\x05\x12.\n*VALIDATE_DEVICE_VERIFICATION_CODE_THROTTLE\x10\x06\x12\x33\n/VALIDATE_CREATE_USER_VERIFICATION_CODE_THROTTLE\x10\x07*8\n\x06Region\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02\x65u\x10\x01\x12\x06\n\x02us\x10\x02\x12\t\n\x05usgov\x10\x03\x12\x06\n\x02\x61u\x10\x04*D\n\x14\x41pplicationShareType\x12\x15\n\x11SHARE_TYPE_RECORD\x10\x00\x12\x15\n\x11SHARE_TYPE_FOLDER\x10\x01*\xa4\x01\n\x15TimeLimitedAccessType\x12$\n INVALID_TIME_LIMITED_ACCESS_TYPE\x10\x00\x12\x19\n\x15USER_ACCESS_TO_RECORD\x10\x01\x12\'\n#USER_OR_TEAM_ACCESS_TO_SHAREDFOLDER\x10\x02\x12!\n\x1dRECORD_ACCESS_TO_SHAREDFOLDER\x10\x03\x42*\n\x18\x63om.keepersecurity.protoB\x0e\x41uthenticationb\x06proto3')

_SUPPORTEDLANGUAGE = DESCRIPTOR.enum_types_by_name['SupportedLanguage']
SupportedLanguage = enum_type_wrapper.EnumTypeWrapper(_SUPPORTEDLANGUAGE)
_LOGINTYPE = DESCRIPTOR.enum_types_by_name['LoginType']
LoginType = enum_type_wrapper.EnumTypeWrapper(_LOGINTYPE)
_DEVICESTATUS = DESCRIPTOR.enum_types_by_name['DeviceStatus']
DeviceStatus = enum_type_wrapper.EnumTypeWrapper(_DEVICESTATUS)
_LICENSESTATUS = DESCRIPTOR.enum_types_by_name['LicenseStatus']
LicenseStatus = enum_type_wrapper.EnumTypeWrapper(_LICENSESTATUS)
_ACCOUNTTYPE = DESCRIPTOR.enum_types_by_name['AccountType']
AccountType = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTTYPE)
_SESSIONTOKENTYPE = DESCRIPTOR.enum_types_by_name['SessionTokenType']
SessionTokenType = enum_type_wrapper.EnumTypeWrapper(_SESSIONTOKENTYPE)
_VERSION = DESCRIPTOR.enum_types_by_name['Version']
Version = enum_type_wrapper.EnumTypeWrapper(_VERSION)
_MASTERPASSWORDREENTRYACTIONTYPE = DESCRIPTOR.enum_types_by_name['MasterPasswordReentryActionType']
MasterPasswordReentryActionType = enum_type_wrapper.EnumTypeWrapper(_MASTERPASSWORDREENTRYACTIONTYPE)
_LOGINMETHOD = DESCRIPTOR.enum_types_by_name['LoginMethod']
LoginMethod = enum_type_wrapper.EnumTypeWrapper(_LOGINMETHOD)
_LOGINSTATE = DESCRIPTOR.enum_types_by_name['LoginState']
LoginState = enum_type_wrapper.EnumTypeWrapper(_LOGINSTATE)
_ENCRYPTEDDATAKEYTYPE = DESCRIPTOR.enum_types_by_name['EncryptedDataKeyType']
EncryptedDataKeyType = enum_type_wrapper.EnumTypeWrapper(_ENCRYPTEDDATAKEYTYPE)
_PASSWORDMETHOD = DESCRIPTOR.enum_types_by_name['PasswordMethod']
PasswordMethod = enum_type_wrapper.EnumTypeWrapper(_PASSWORDMETHOD)
_TWOFACTORPUSHTYPE = DESCRIPTOR.enum_types_by_name['TwoFactorPushType']
TwoFactorPushType = enum_type_wrapper.EnumTypeWrapper(_TWOFACTORPUSHTYPE)
_TWOFACTORVALUETYPE = DESCRIPTOR.enum_types_by_name['TwoFactorValueType']
TwoFactorValueType = enum_type_wrapper.EnumTypeWrapper(_TWOFACTORVALUETYPE)
_TWOFACTORCHANNELTYPE = DESCRIPTOR.enum_types_by_name['TwoFactorChannelType']
TwoFactorChannelType = enum_type_wrapper.EnumTypeWrapper(_TWOFACTORCHANNELTYPE)
_TWOFACTOREXPIRATION = DESCRIPTOR.enum_types_by_name['TwoFactorExpiration']
TwoFactorExpiration = enum_type_wrapper.EnumTypeWrapper(_TWOFACTOREXPIRATION)
_LICENSETYPE = DESCRIPTOR.enum_types_by_name['LicenseType']
LicenseType = enum_type_wrapper.EnumTypeWrapper(_LICENSETYPE)
_OBJECTTYPES = DESCRIPTOR.enum_types_by_name['ObjectTypes']
ObjectTypes = enum_type_wrapper.EnumTypeWrapper(_OBJECTTYPES)
_ALTERNATEAUTHENTICATIONTYPE = DESCRIPTOR.enum_types_by_name['AlternateAuthenticationType']
AlternateAuthenticationType = enum_type_wrapper.EnumTypeWrapper(_ALTERNATEAUTHENTICATIONTYPE)
_THROTTLETYPE = DESCRIPTOR.enum_types_by_name['ThrottleType']
ThrottleType = enum_type_wrapper.EnumTypeWrapper(_THROTTLETYPE)
_REGION = DESCRIPTOR.enum_types_by_name['Region']
Region = enum_type_wrapper.EnumTypeWrapper(_REGION)
_APPLICATIONSHARETYPE = DESCRIPTOR.enum_types_by_name['ApplicationShareType']
ApplicationShareType = enum_type_wrapper.EnumTypeWrapper(_APPLICATIONSHARETYPE)
_TIMELIMITEDACCESSTYPE = DESCRIPTOR.enum_types_by_name['TimeLimitedAccessType']
TimeLimitedAccessType = enum_type_wrapper.EnumTypeWrapper(_TIMELIMITEDACCESSTYPE)
ENGLISH = 0
ARABIC = 1
BRITISH = 2
CHINESE = 3
CHINESE_HONG_KONG = 4
CHINESE_TAIWAN = 5
DUTCH = 6
FRENCH = 7
GERMAN = 8
GREEK = 9
HEBREW = 10
ITALIAN = 11
JAPANESE = 12
KOREAN = 13
POLISH = 14
PORTUGUESE = 15
PORTUGUESE_BRAZIL = 16
ROMANIAN = 17
RUSSIAN = 18
SLOVAK = 19
SPANISH = 20
NORMAL = 0
SSO = 1
BIO = 2
ALTERNATE = 3
OFFLINE = 4
FORGOT_PASSWORD = 5
DEVICE_NEEDS_APPROVAL = 0
DEVICE_OK = 1
DEVICE_DISABLED_BY_USER = 2
DEVICE_LOCKED_BY_ADMIN = 3
OTHER = 0
ACTIVE = 1
EXPIRED = 2
DISABLED = 3
CONSUMER = 0
FAMILY = 1
ENTERPRISE = 2
NO_RESTRICTION = 0
ACCOUNT_RECOVERY = 1
SHARE_ACCOUNT = 2
PURCHASE = 3
RESTRICT = 4
ACCEPT_INVITE = 5
SUPPORT_SERVER = 6
ENTERPRISE_CREATION = 7
EXPIRED_BUT_ALLOWED_TO_SYNC = 8
invalid_version = 0
default_version = 1
second_version = 2
UNMASK = 0
COPY = 1
INVALID_LOGINMETHOD = 0
EXISTING_ACCOUNT = 1
SSO_DOMAIN = 2
AFTER_SSO = 3
NEW_ACCOUNT = 4
INVALID_LOGINSTATE = 0
LOGGED_OUT = 1
DEVICE_APPROVAL_REQUIRED = 2
DEVICE_LOCKED = 3
ACCOUNT_LOCKED = 4
DEVICE_ACCOUNT_LOCKED = 5
UPGRADE = 6
LICENSE_EXPIRED = 7
REGION_REDIRECT = 8
REDIRECT_CLOUD_SSO = 9
REDIRECT_ONSITE_SSO = 10
REQUIRES_2FA = 12
REQUIRES_AUTH_HASH = 13
REQUIRES_USERNAME = 14
AFTER_CLOUD_SSO_LOGIN = 15
REQUIRES_ACCOUNT_CREATION = 16
REQUIRES_DEVICE_ENCRYPTED_DATA_KEY = 17
LOGIN_TOKEN_EXPIRED = 18
LOGGED_IN = 99
NO_KEY = 0
BY_DEVICE_PUBLIC_KEY = 1
BY_PASSWORD = 2
BY_ALTERNATE = 3
BY_BIO = 4
ENTERED = 0
BIOMETRICS = 1
TWO_FA_PUSH_NONE = 0
TWO_FA_PUSH_SMS = 1
TWO_FA_PUSH_KEEPER = 2
TWO_FA_PUSH_DUO_PUSH = 3
TWO_FA_PUSH_DUO_TEXT = 4
TWO_FA_PUSH_DUO_CALL = 5
TWO_FA_PUSH_DNA = 6
TWO_FA_CODE_NONE = 0
TWO_FA_CODE_TOTP = 1
TWO_FA_CODE_SMS = 2
TWO_FA_CODE_DUO = 3
TWO_FA_CODE_RSA = 4
TWO_FA_RESP_U2F = 5
TWO_FA_RESP_WEBAUTHN = 6
TWO_FA_CODE_DNA = 7
TWO_FA_CT_NONE = 0
TWO_FA_CT_TOTP = 1
TWO_FA_CT_SMS = 2
TWO_FA_CT_DUO = 3
TWO_FA_CT_RSA = 4
TWO_FA_CT_BACKUP = 5
TWO_FA_CT_U2F = 6
TWO_FA_CT_WEBAUTHN = 7
TWO_FA_CT_KEEPER = 8
TWO_FA_CT_DNA = 9
TWO_FA_EXP_IMMEDIATELY = 0
TWO_FA_EXP_5_MINUTES = 1
TWO_FA_EXP_12_HOURS = 2
TWO_FA_EXP_24_HOURS = 3
TWO_FA_EXP_30_DAYS = 4
TWO_FA_EXP_NEVER = 5
VAULT = 0
CHAT = 1
STORAGE = 2
BREACHWATCH = 3
RECORD = 0
SHARED_FOLDER_USER = 1
SHARED_FOLDER_TEAM = 2
USER_FOLDER = 3
TEAM_USER = 4
ALTERNATE_MASTER_PASSWORD = 0
BIOMETRIC = 1
ACCOUNT_RECOVER = 2
PASSWORD_RETRY_THROTTLE = 0
PASSWORD_RETRY_LEGACY_THROTTLE = 1
TWO_FA_THROTTLE = 2
TWO_FA_LEGACY_THROTTLE = 3
QA_RETRY_THROTTLE = 4
ACCOUNT_RECOVER_THROTTLE = 5
VALIDATE_DEVICE_VERIFICATION_CODE_THROTTLE = 6
VALIDATE_CREATE_USER_VERIFICATION_CODE_THROTTLE = 7
UNKNOWN = 0
eu = 1
us = 2
usgov = 3
au = 4
SHARE_TYPE_RECORD = 0
SHARE_TYPE_FOLDER = 1
INVALID_TIME_LIMITED_ACCESS_TYPE = 0
USER_ACCESS_TO_RECORD = 1
USER_OR_TEAM_ACCESS_TO_SHAREDFOLDER = 2
RECORD_ACCESS_TO_SHAREDFOLDER = 3


_APIREQUEST = DESCRIPTOR.message_types_by_name['ApiRequest']
_APIREQUESTPAYLOAD = DESCRIPTOR.message_types_by_name['ApiRequestPayload']
_TRANSFORM = DESCRIPTOR.message_types_by_name['Transform']
_DEVICEREQUEST = DESCRIPTOR.message_types_by_name['DeviceRequest']
_AUTHREQUEST = DESCRIPTOR.message_types_by_name['AuthRequest']
_NEWUSERMINIMUMPARAMS = DESCRIPTOR.message_types_by_name['NewUserMinimumParams']
_PRELOGINREQUEST = DESCRIPTOR.message_types_by_name['PreLoginRequest']
_LOGINREQUEST = DESCRIPTOR.message_types_by_name['LoginRequest']
_DEVICERESPONSE = DESCRIPTOR.message_types_by_name['DeviceResponse']
_SALT = DESCRIPTOR.message_types_by_name['Salt']
_TWOFACTORCHANNEL = DESCRIPTOR.message_types_by_name['TwoFactorChannel']
_STARTLOGINREQUEST = DESCRIPTOR.message_types_by_name['StartLoginRequest']
_LOGINRESPONSE = DESCRIPTOR.message_types_by_name['LoginResponse']
_SSOUSERINFO = DESCRIPTOR.message_types_by_name['SsoUserInfo']
_PRELOGINRESPONSE = DESCRIPTOR.message_types_by_name['PreLoginResponse']
_LOGINASUSERREQUEST = DESCRIPTOR.message_types_by_name['LoginAsUserRequest']
_LOGINASUSERRESPONSE = DESCRIPTOR.message_types_by_name['LoginAsUserResponse']
_VALIDATEAUTHHASHREQUEST = DESCRIPTOR.message_types_by_name['ValidateAuthHashRequest']
_TWOFACTORCHANNELINFO = DESCRIPTOR.message_types_by_name['TwoFactorChannelInfo']
_TWOFACTORDUOSTATUS = DESCRIPTOR.message_types_by_name['TwoFactorDuoStatus']
_TWOFACTORADDREQUEST = DESCRIPTOR.message_types_by_name['TwoFactorAddRequest']
_TWOFACTORRENAMEREQUEST = DESCRIPTOR.message_types_by_name['TwoFactorRenameRequest']
_TWOFACTORADDRESPONSE = DESCRIPTOR.message_types_by_name['TwoFactorAddResponse']
_TWOFACTORDELETEREQUEST = DESCRIPTOR.message_types_by_name['TwoFactorDeleteRequest']
_TWOFACTORLISTRESPONSE = DESCRIPTOR.message_types_by_name['TwoFactorListResponse']
_TWOFACTORUPDATEEXPIRATIONREQUEST = DESCRIPTOR.message_types_by_name['TwoFactorUpdateExpirationRequest']
_TWOFACTORVALIDATEREQUEST = DESCRIPTOR.message_types_by_name['TwoFactorValidateRequest']
_TWOFACTORVALIDATERESPONSE = DESCRIPTOR.message_types_by_name['TwoFactorValidateResponse']
_TWOFACTORSENDPUSHREQUEST = DESCRIPTOR.message_types_by_name['TwoFactorSendPushRequest']
_LICENSE = DESCRIPTOR.message_types_by_name['License']
_OWNERLESSRECORD = DESCRIPTOR.message_types_by_name['OwnerlessRecord']
_OWNERLESSRECORDS = DESCRIPTOR.message_types_by_name['OwnerlessRecords']
_USERAUTHREQUEST = DESCRIPTOR.message_types_by_name['UserAuthRequest']
_UIDREQUEST = DESCRIPTOR.message_types_by_name['UidRequest']
_DEVICEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['DeviceUpdateRequest']
_REGISTERDEVICEINREGIONREQUEST = DESCRIPTOR.message_types_by_name['RegisterDeviceInRegionRequest']
_REGISTRATIONREQUEST = DESCRIPTOR.message_types_by_name['RegistrationRequest']
_CONVERTUSERTOV3REQUEST = DESCRIPTOR.message_types_by_name['ConvertUserToV3Request']
_REVISIONRESPONSE = DESCRIPTOR.message_types_by_name['RevisionResponse']
_CHANGEEMAILREQUEST = DESCRIPTOR.message_types_by_name['ChangeEmailRequest']
_CHANGEEMAILRESPONSE = DESCRIPTOR.message_types_by_name['ChangeEmailResponse']
_EMAILVERIFICATIONLINKRESPONSE = DESCRIPTOR.message_types_by_name['EmailVerificationLinkResponse']
_SECURITYDATA = DESCRIPTOR.message_types_by_name['SecurityData']
_SECURITYDATAREQUEST = DESCRIPTOR.message_types_by_name['SecurityDataRequest']
_SECURITYREPORTINCREMENTALDATA = DESCRIPTOR.message_types_by_name['SecurityReportIncrementalData']
_SECURITYREPORT = DESCRIPTOR.message_types_by_name['SecurityReport']
_SECURITYREPORTSAVEREQUEST = DESCRIPTOR.message_types_by_name['SecurityReportSaveRequest']
_SECURITYREPORTREQUEST = DESCRIPTOR.message_types_by_name['SecurityReportRequest']
_SECURITYREPORTRESPONSE = DESCRIPTOR.message_types_by_name['SecurityReportResponse']
_REUSEDPASSWORDSREQUEST = DESCRIPTOR.message_types_by_name['ReusedPasswordsRequest']
_SUMMARYCONSOLEREPORT = DESCRIPTOR.message_types_by_name['SummaryConsoleReport']
_CHANGETOKEYTYPEONE = DESCRIPTOR.message_types_by_name['ChangeToKeyTypeOne']
_CHANGETOKEYTYPEONEREQUEST = DESCRIPTOR.message_types_by_name['ChangeToKeyTypeOneRequest']
_CHANGETOKEYTYPEONESTATUS = DESCRIPTOR.message_types_by_name['ChangeToKeyTypeOneStatus']
_CHANGETOKEYTYPEONERESPONSE = DESCRIPTOR.message_types_by_name['ChangeToKeyTypeOneResponse']
_SETKEY = DESCRIPTOR.message_types_by_name['SetKey']
_SETKEYREQUEST = DESCRIPTOR.message_types_by_name['SetKeyRequest']
_CREATEUSERREQUEST = DESCRIPTOR.message_types_by_name['CreateUserRequest']
_NODEENFORCEMENTADDORUPDATEREQUEST = DESCRIPTOR.message_types_by_name['NodeEnforcementAddOrUpdateRequest']
_NODEENFORCEMENTREMOVEREQUEST = DESCRIPTOR.message_types_by_name['NodeEnforcementRemoveRequest']
_APIREQUESTBYKEY = DESCRIPTOR.message_types_by_name['ApiRequestByKey']
_APIREQUESTBYKATOKAKEY = DESCRIPTOR.message_types_by_name['ApiRequestByKAtoKAKey']
_MEMCACHEREQUEST = DESCRIPTOR.message_types_by_name['MemcacheRequest']
_MEMCACHERESPONSE = DESCRIPTOR.message_types_by_name['MemcacheResponse']
_MASTERPASSWORDREENTRYREQUEST = DESCRIPTOR.message_types_by_name['MasterPasswordReentryRequest']
_DEVICEREGISTRATIONREQUEST = DESCRIPTOR.message_types_by_name['DeviceRegistrationRequest']
_DEVICEVERIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['DeviceVerificationRequest']
_DEVICEVERIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['DeviceVerificationResponse']
_DEVICEAPPROVALREQUEST = DESCRIPTOR.message_types_by_name['DeviceApprovalRequest']
_DEVICEAPPROVALRESPONSE = DESCRIPTOR.message_types_by_name['DeviceApprovalResponse']
_APPROVEDEVICEREQUEST = DESCRIPTOR.message_types_by_name['ApproveDeviceRequest']
_ENTERPRISEUSERALIASREQUEST = DESCRIPTOR.message_types_by_name['EnterpriseUserAliasRequest']
_ENTERPRISEUSERADDALIASREQUEST = DESCRIPTOR.message_types_by_name['EnterpriseUserAddAliasRequest']
_DEVICE = DESCRIPTOR.message_types_by_name['Device']
_REGISTERDEVICEDATAKEYREQUEST = DESCRIPTOR.message_types_by_name['RegisterDeviceDataKeyRequest']
_VALIDATECREATEUSERVERIFICATIONCODEREQUEST = DESCRIPTOR.message_types_by_name['ValidateCreateUserVerificationCodeRequest']
_VALIDATEDEVICEVERIFICATIONCODEREQUEST = DESCRIPTOR.message_types_by_name['ValidateDeviceVerificationCodeRequest']
_SENDSESSIONMESSAGEREQUEST = DESCRIPTOR.message_types_by_name['SendSessionMessageRequest']
_GLOBALUSERACCOUNT = DESCRIPTOR.message_types_by_name['GlobalUserAccount']
_ACCOUNTUSERNAME = DESCRIPTOR.message_types_by_name['AccountUsername']
_SSOSERVICEPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['SsoServiceProviderRequest']
_SSOSERVICEPROVIDERRESPONSE = DESCRIPTOR.message_types_by_name['SsoServiceProviderResponse']
_USERSETTINGREQUEST = DESCRIPTOR.message_types_by_name['UserSettingRequest']
_THROTTLESTATE = DESCRIPTOR.message_types_by_name['ThrottleState']
_THROTTLESTATE2 = DESCRIPTOR.message_types_by_name['ThrottleState2']
_DEVICEINFORMATION = DESCRIPTOR.message_types_by_name['DeviceInformation']
_USERSETTING = DESCRIPTOR.message_types_by_name['UserSetting']
_USERDATAKEYREQUEST = DESCRIPTOR.message_types_by_name['UserDataKeyRequest']
_ENTERPRISEUSERIDDATAKEYPAIR = DESCRIPTOR.message_types_by_name['EnterpriseUserIdDataKeyPair']
_USERDATAKEY = DESCRIPTOR.message_types_by_name['UserDataKey']
_USERDATAKEYRESPONSE = DESCRIPTOR.message_types_by_name['UserDataKeyResponse']
_MASTERPASSWORDRECOVERYVERIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['MasterPasswordRecoveryVerificationRequest']
_GETSECURITYQUESTIONV3REQUEST = DESCRIPTOR.message_types_by_name['GetSecurityQuestionV3Request']
_GETSECURITYQUESTIONV3RESPONSE = DESCRIPTOR.message_types_by_name['GetSecurityQuestionV3Response']
_GETDATAKEYBACKUPV3REQUEST = DESCRIPTOR.message_types_by_name['GetDataKeyBackupV3Request']
_PASSWORDRULES = DESCRIPTOR.message_types_by_name['PasswordRules']
_GETDATAKEYBACKUPV3RESPONSE = DESCRIPTOR.message_types_by_name['GetDataKeyBackupV3Response']
_GETPUBLICKEYSREQUEST = DESCRIPTOR.message_types_by_name['GetPublicKeysRequest']
_PUBLICKEYRESPONSE = DESCRIPTOR.message_types_by_name['PublicKeyResponse']
_GETPUBLICKEYSRESPONSE = DESCRIPTOR.message_types_by_name['GetPublicKeysResponse']
_SETECCKEYPAIRREQUEST = DESCRIPTOR.message_types_by_name['SetEccKeyPairRequest']
_ADDAPPSHARESREQUEST = DESCRIPTOR.message_types_by_name['AddAppSharesRequest']
_REMOVEAPPSHARESREQUEST = DESCRIPTOR.message_types_by_name['RemoveAppSharesRequest']
_APPSHAREADD = DESCRIPTOR.message_types_by_name['AppShareAdd']
_APPSHARE = DESCRIPTOR.message_types_by_name['AppShare']
_ADDAPPCLIENTREQUEST = DESCRIPTOR.message_types_by_name['AddAppClientRequest']
_REMOVEAPPCLIENTSREQUEST = DESCRIPTOR.message_types_by_name['RemoveAppClientsRequest']
_ADDEXTERNALSHAREREQUEST = DESCRIPTOR.message_types_by_name['AddExternalShareRequest']
_APPCLIENT = DESCRIPTOR.message_types_by_name['AppClient']
_GETAPPINFOREQUEST = DESCRIPTOR.message_types_by_name['GetAppInfoRequest']
_APPINFO = DESCRIPTOR.message_types_by_name['AppInfo']
_GETAPPINFORESPONSE = DESCRIPTOR.message_types_by_name['GetAppInfoResponse']
_APPLICATIONSUMMARY = DESCRIPTOR.message_types_by_name['ApplicationSummary']
_GETAPPLICATIONSSUMMARYRESPONSE = DESCRIPTOR.message_types_by_name['GetApplicationsSummaryResponse']
_GETVERIFICATIONTOKENREQUEST = DESCRIPTOR.message_types_by_name['GetVerificationTokenRequest']
_GETVERIFICATIONTOKENRESPONSE = DESCRIPTOR.message_types_by_name['GetVerificationTokenResponse']
_SENDSHAREINVITEREQUEST = DESCRIPTOR.message_types_by_name['SendShareInviteRequest']
_TIMELIMITEDACCESSREQUEST = DESCRIPTOR.message_types_by_name['TimeLimitedAccessRequest']
_TIMELIMITEDACCESSRESPONSE = DESCRIPTOR.message_types_by_name['TimeLimitedAccessResponse']
_REQUESTDOWNLOADREQUEST = DESCRIPTOR.message_types_by_name['RequestDownloadRequest']
_REQUESTDOWNLOADRESPONSE = DESCRIPTOR.message_types_by_name['RequestDownloadResponse']
_DOWNLOAD = DESCRIPTOR.message_types_by_name['Download']
_DELETEUSERREQUEST = DESCRIPTOR.message_types_by_name['DeleteUserRequest']
ApiRequest = _reflection.GeneratedProtocolMessageType('ApiRequest', (_message.Message,), {
  'DESCRIPTOR' : _APIREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ApiRequest)
  })
_sym_db.RegisterMessage(ApiRequest)

ApiRequestPayload = _reflection.GeneratedProtocolMessageType('ApiRequestPayload', (_message.Message,), {
  'DESCRIPTOR' : _APIREQUESTPAYLOAD,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ApiRequestPayload)
  })
_sym_db.RegisterMessage(ApiRequestPayload)

Transform = _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORM,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.Transform)
  })
_sym_db.RegisterMessage(Transform)

DeviceRequest = _reflection.GeneratedProtocolMessageType('DeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceRequest)
  })
_sym_db.RegisterMessage(DeviceRequest)

AuthRequest = _reflection.GeneratedProtocolMessageType('AuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AuthRequest)
  })
_sym_db.RegisterMessage(AuthRequest)

NewUserMinimumParams = _reflection.GeneratedProtocolMessageType('NewUserMinimumParams', (_message.Message,), {
  'DESCRIPTOR' : _NEWUSERMINIMUMPARAMS,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.NewUserMinimumParams)
  })
_sym_db.RegisterMessage(NewUserMinimumParams)

PreLoginRequest = _reflection.GeneratedProtocolMessageType('PreLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRELOGINREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.PreLoginRequest)
  })
_sym_db.RegisterMessage(PreLoginRequest)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.LoginRequest)
  })
_sym_db.RegisterMessage(LoginRequest)

DeviceResponse = _reflection.GeneratedProtocolMessageType('DeviceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICERESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceResponse)
  })
_sym_db.RegisterMessage(DeviceResponse)

Salt = _reflection.GeneratedProtocolMessageType('Salt', (_message.Message,), {
  'DESCRIPTOR' : _SALT,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.Salt)
  })
_sym_db.RegisterMessage(Salt)

TwoFactorChannel = _reflection.GeneratedProtocolMessageType('TwoFactorChannel', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORCHANNEL,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorChannel)
  })
_sym_db.RegisterMessage(TwoFactorChannel)

StartLoginRequest = _reflection.GeneratedProtocolMessageType('StartLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTLOGINREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.StartLoginRequest)
  })
_sym_db.RegisterMessage(StartLoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.LoginResponse)
  })
_sym_db.RegisterMessage(LoginResponse)

SsoUserInfo = _reflection.GeneratedProtocolMessageType('SsoUserInfo', (_message.Message,), {
  'DESCRIPTOR' : _SSOUSERINFO,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SsoUserInfo)
  })
_sym_db.RegisterMessage(SsoUserInfo)

PreLoginResponse = _reflection.GeneratedProtocolMessageType('PreLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRELOGINRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.PreLoginResponse)
  })
_sym_db.RegisterMessage(PreLoginResponse)

LoginAsUserRequest = _reflection.GeneratedProtocolMessageType('LoginAsUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINASUSERREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.LoginAsUserRequest)
  })
_sym_db.RegisterMessage(LoginAsUserRequest)

LoginAsUserResponse = _reflection.GeneratedProtocolMessageType('LoginAsUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINASUSERRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.LoginAsUserResponse)
  })
_sym_db.RegisterMessage(LoginAsUserResponse)

ValidateAuthHashRequest = _reflection.GeneratedProtocolMessageType('ValidateAuthHashRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEAUTHHASHREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ValidateAuthHashRequest)
  })
_sym_db.RegisterMessage(ValidateAuthHashRequest)

TwoFactorChannelInfo = _reflection.GeneratedProtocolMessageType('TwoFactorChannelInfo', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORCHANNELINFO,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorChannelInfo)
  })
_sym_db.RegisterMessage(TwoFactorChannelInfo)

TwoFactorDuoStatus = _reflection.GeneratedProtocolMessageType('TwoFactorDuoStatus', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORDUOSTATUS,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorDuoStatus)
  })
_sym_db.RegisterMessage(TwoFactorDuoStatus)

TwoFactorAddRequest = _reflection.GeneratedProtocolMessageType('TwoFactorAddRequest', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORADDREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorAddRequest)
  })
_sym_db.RegisterMessage(TwoFactorAddRequest)

TwoFactorRenameRequest = _reflection.GeneratedProtocolMessageType('TwoFactorRenameRequest', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORRENAMEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorRenameRequest)
  })
_sym_db.RegisterMessage(TwoFactorRenameRequest)

TwoFactorAddResponse = _reflection.GeneratedProtocolMessageType('TwoFactorAddResponse', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORADDRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorAddResponse)
  })
_sym_db.RegisterMessage(TwoFactorAddResponse)

TwoFactorDeleteRequest = _reflection.GeneratedProtocolMessageType('TwoFactorDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORDELETEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorDeleteRequest)
  })
_sym_db.RegisterMessage(TwoFactorDeleteRequest)

TwoFactorListResponse = _reflection.GeneratedProtocolMessageType('TwoFactorListResponse', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORLISTRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorListResponse)
  })
_sym_db.RegisterMessage(TwoFactorListResponse)

TwoFactorUpdateExpirationRequest = _reflection.GeneratedProtocolMessageType('TwoFactorUpdateExpirationRequest', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORUPDATEEXPIRATIONREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorUpdateExpirationRequest)
  })
_sym_db.RegisterMessage(TwoFactorUpdateExpirationRequest)

TwoFactorValidateRequest = _reflection.GeneratedProtocolMessageType('TwoFactorValidateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORVALIDATEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorValidateRequest)
  })
_sym_db.RegisterMessage(TwoFactorValidateRequest)

TwoFactorValidateResponse = _reflection.GeneratedProtocolMessageType('TwoFactorValidateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORVALIDATERESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorValidateResponse)
  })
_sym_db.RegisterMessage(TwoFactorValidateResponse)

TwoFactorSendPushRequest = _reflection.GeneratedProtocolMessageType('TwoFactorSendPushRequest', (_message.Message,), {
  'DESCRIPTOR' : _TWOFACTORSENDPUSHREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TwoFactorSendPushRequest)
  })
_sym_db.RegisterMessage(TwoFactorSendPushRequest)

License = _reflection.GeneratedProtocolMessageType('License', (_message.Message,), {
  'DESCRIPTOR' : _LICENSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.License)
  })
_sym_db.RegisterMessage(License)

OwnerlessRecord = _reflection.GeneratedProtocolMessageType('OwnerlessRecord', (_message.Message,), {
  'DESCRIPTOR' : _OWNERLESSRECORD,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.OwnerlessRecord)
  })
_sym_db.RegisterMessage(OwnerlessRecord)

OwnerlessRecords = _reflection.GeneratedProtocolMessageType('OwnerlessRecords', (_message.Message,), {
  'DESCRIPTOR' : _OWNERLESSRECORDS,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.OwnerlessRecords)
  })
_sym_db.RegisterMessage(OwnerlessRecords)

UserAuthRequest = _reflection.GeneratedProtocolMessageType('UserAuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERAUTHREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.UserAuthRequest)
  })
_sym_db.RegisterMessage(UserAuthRequest)

UidRequest = _reflection.GeneratedProtocolMessageType('UidRequest', (_message.Message,), {
  'DESCRIPTOR' : _UIDREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.UidRequest)
  })
_sym_db.RegisterMessage(UidRequest)

DeviceUpdateRequest = _reflection.GeneratedProtocolMessageType('DeviceUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEUPDATEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceUpdateRequest)
  })
_sym_db.RegisterMessage(DeviceUpdateRequest)

RegisterDeviceInRegionRequest = _reflection.GeneratedProtocolMessageType('RegisterDeviceInRegionRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERDEVICEINREGIONREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RegisterDeviceInRegionRequest)
  })
_sym_db.RegisterMessage(RegisterDeviceInRegionRequest)

RegistrationRequest = _reflection.GeneratedProtocolMessageType('RegistrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRATIONREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RegistrationRequest)
  })
_sym_db.RegisterMessage(RegistrationRequest)

ConvertUserToV3Request = _reflection.GeneratedProtocolMessageType('ConvertUserToV3Request', (_message.Message,), {
  'DESCRIPTOR' : _CONVERTUSERTOV3REQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ConvertUserToV3Request)
  })
_sym_db.RegisterMessage(ConvertUserToV3Request)

RevisionResponse = _reflection.GeneratedProtocolMessageType('RevisionResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVISIONRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RevisionResponse)
  })
_sym_db.RegisterMessage(RevisionResponse)

ChangeEmailRequest = _reflection.GeneratedProtocolMessageType('ChangeEmailRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEEMAILREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ChangeEmailRequest)
  })
_sym_db.RegisterMessage(ChangeEmailRequest)

ChangeEmailResponse = _reflection.GeneratedProtocolMessageType('ChangeEmailResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEEMAILRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ChangeEmailResponse)
  })
_sym_db.RegisterMessage(ChangeEmailResponse)

EmailVerificationLinkResponse = _reflection.GeneratedProtocolMessageType('EmailVerificationLinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _EMAILVERIFICATIONLINKRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.EmailVerificationLinkResponse)
  })
_sym_db.RegisterMessage(EmailVerificationLinkResponse)

SecurityData = _reflection.GeneratedProtocolMessageType('SecurityData', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYDATA,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SecurityData)
  })
_sym_db.RegisterMessage(SecurityData)

SecurityDataRequest = _reflection.GeneratedProtocolMessageType('SecurityDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYDATAREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SecurityDataRequest)
  })
_sym_db.RegisterMessage(SecurityDataRequest)

SecurityReportIncrementalData = _reflection.GeneratedProtocolMessageType('SecurityReportIncrementalData', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYREPORTINCREMENTALDATA,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SecurityReportIncrementalData)
  })
_sym_db.RegisterMessage(SecurityReportIncrementalData)

SecurityReport = _reflection.GeneratedProtocolMessageType('SecurityReport', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYREPORT,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SecurityReport)
  })
_sym_db.RegisterMessage(SecurityReport)

SecurityReportSaveRequest = _reflection.GeneratedProtocolMessageType('SecurityReportSaveRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYREPORTSAVEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SecurityReportSaveRequest)
  })
_sym_db.RegisterMessage(SecurityReportSaveRequest)

SecurityReportRequest = _reflection.GeneratedProtocolMessageType('SecurityReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYREPORTREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SecurityReportRequest)
  })
_sym_db.RegisterMessage(SecurityReportRequest)

SecurityReportResponse = _reflection.GeneratedProtocolMessageType('SecurityReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYREPORTRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SecurityReportResponse)
  })
_sym_db.RegisterMessage(SecurityReportResponse)

ReusedPasswordsRequest = _reflection.GeneratedProtocolMessageType('ReusedPasswordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REUSEDPASSWORDSREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ReusedPasswordsRequest)
  })
_sym_db.RegisterMessage(ReusedPasswordsRequest)

SummaryConsoleReport = _reflection.GeneratedProtocolMessageType('SummaryConsoleReport', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYCONSOLEREPORT,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SummaryConsoleReport)
  })
_sym_db.RegisterMessage(SummaryConsoleReport)

ChangeToKeyTypeOne = _reflection.GeneratedProtocolMessageType('ChangeToKeyTypeOne', (_message.Message,), {
  'DESCRIPTOR' : _CHANGETOKEYTYPEONE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ChangeToKeyTypeOne)
  })
_sym_db.RegisterMessage(ChangeToKeyTypeOne)

ChangeToKeyTypeOneRequest = _reflection.GeneratedProtocolMessageType('ChangeToKeyTypeOneRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGETOKEYTYPEONEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ChangeToKeyTypeOneRequest)
  })
_sym_db.RegisterMessage(ChangeToKeyTypeOneRequest)

ChangeToKeyTypeOneStatus = _reflection.GeneratedProtocolMessageType('ChangeToKeyTypeOneStatus', (_message.Message,), {
  'DESCRIPTOR' : _CHANGETOKEYTYPEONESTATUS,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ChangeToKeyTypeOneStatus)
  })
_sym_db.RegisterMessage(ChangeToKeyTypeOneStatus)

ChangeToKeyTypeOneResponse = _reflection.GeneratedProtocolMessageType('ChangeToKeyTypeOneResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGETOKEYTYPEONERESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ChangeToKeyTypeOneResponse)
  })
_sym_db.RegisterMessage(ChangeToKeyTypeOneResponse)

SetKey = _reflection.GeneratedProtocolMessageType('SetKey', (_message.Message,), {
  'DESCRIPTOR' : _SETKEY,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SetKey)
  })
_sym_db.RegisterMessage(SetKey)

SetKeyRequest = _reflection.GeneratedProtocolMessageType('SetKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETKEYREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SetKeyRequest)
  })
_sym_db.RegisterMessage(SetKeyRequest)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

NodeEnforcementAddOrUpdateRequest = _reflection.GeneratedProtocolMessageType('NodeEnforcementAddOrUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEENFORCEMENTADDORUPDATEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.NodeEnforcementAddOrUpdateRequest)
  })
_sym_db.RegisterMessage(NodeEnforcementAddOrUpdateRequest)

NodeEnforcementRemoveRequest = _reflection.GeneratedProtocolMessageType('NodeEnforcementRemoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEENFORCEMENTREMOVEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.NodeEnforcementRemoveRequest)
  })
_sym_db.RegisterMessage(NodeEnforcementRemoveRequest)

ApiRequestByKey = _reflection.GeneratedProtocolMessageType('ApiRequestByKey', (_message.Message,), {
  'DESCRIPTOR' : _APIREQUESTBYKEY,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ApiRequestByKey)
  })
_sym_db.RegisterMessage(ApiRequestByKey)

ApiRequestByKAtoKAKey = _reflection.GeneratedProtocolMessageType('ApiRequestByKAtoKAKey', (_message.Message,), {
  'DESCRIPTOR' : _APIREQUESTBYKATOKAKEY,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ApiRequestByKAtoKAKey)
  })
_sym_db.RegisterMessage(ApiRequestByKAtoKAKey)

MemcacheRequest = _reflection.GeneratedProtocolMessageType('MemcacheRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEMCACHEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.MemcacheRequest)
  })
_sym_db.RegisterMessage(MemcacheRequest)

MemcacheResponse = _reflection.GeneratedProtocolMessageType('MemcacheResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEMCACHERESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.MemcacheResponse)
  })
_sym_db.RegisterMessage(MemcacheResponse)

MasterPasswordReentryRequest = _reflection.GeneratedProtocolMessageType('MasterPasswordReentryRequest', (_message.Message,), {
  'DESCRIPTOR' : _MASTERPASSWORDREENTRYREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.MasterPasswordReentryRequest)
  })
_sym_db.RegisterMessage(MasterPasswordReentryRequest)

DeviceRegistrationRequest = _reflection.GeneratedProtocolMessageType('DeviceRegistrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEREGISTRATIONREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceRegistrationRequest)
  })
_sym_db.RegisterMessage(DeviceRegistrationRequest)

DeviceVerificationRequest = _reflection.GeneratedProtocolMessageType('DeviceVerificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEVERIFICATIONREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceVerificationRequest)
  })
_sym_db.RegisterMessage(DeviceVerificationRequest)

DeviceVerificationResponse = _reflection.GeneratedProtocolMessageType('DeviceVerificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEVERIFICATIONRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceVerificationResponse)
  })
_sym_db.RegisterMessage(DeviceVerificationResponse)

DeviceApprovalRequest = _reflection.GeneratedProtocolMessageType('DeviceApprovalRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEAPPROVALREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceApprovalRequest)
  })
_sym_db.RegisterMessage(DeviceApprovalRequest)

DeviceApprovalResponse = _reflection.GeneratedProtocolMessageType('DeviceApprovalResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEAPPROVALRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceApprovalResponse)
  })
_sym_db.RegisterMessage(DeviceApprovalResponse)

ApproveDeviceRequest = _reflection.GeneratedProtocolMessageType('ApproveDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEDEVICEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ApproveDeviceRequest)
  })
_sym_db.RegisterMessage(ApproveDeviceRequest)

EnterpriseUserAliasRequest = _reflection.GeneratedProtocolMessageType('EnterpriseUserAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERALIASREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.EnterpriseUserAliasRequest)
  })
_sym_db.RegisterMessage(EnterpriseUserAliasRequest)

EnterpriseUserAddAliasRequest = _reflection.GeneratedProtocolMessageType('EnterpriseUserAddAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERADDALIASREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.EnterpriseUserAddAliasRequest)
  })
_sym_db.RegisterMessage(EnterpriseUserAddAliasRequest)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.Device)
  })
_sym_db.RegisterMessage(Device)

RegisterDeviceDataKeyRequest = _reflection.GeneratedProtocolMessageType('RegisterDeviceDataKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERDEVICEDATAKEYREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RegisterDeviceDataKeyRequest)
  })
_sym_db.RegisterMessage(RegisterDeviceDataKeyRequest)

ValidateCreateUserVerificationCodeRequest = _reflection.GeneratedProtocolMessageType('ValidateCreateUserVerificationCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATECREATEUSERVERIFICATIONCODEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ValidateCreateUserVerificationCodeRequest)
  })
_sym_db.RegisterMessage(ValidateCreateUserVerificationCodeRequest)

ValidateDeviceVerificationCodeRequest = _reflection.GeneratedProtocolMessageType('ValidateDeviceVerificationCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDEVICEVERIFICATIONCODEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ValidateDeviceVerificationCodeRequest)
  })
_sym_db.RegisterMessage(ValidateDeviceVerificationCodeRequest)

SendSessionMessageRequest = _reflection.GeneratedProtocolMessageType('SendSessionMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDSESSIONMESSAGEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SendSessionMessageRequest)
  })
_sym_db.RegisterMessage(SendSessionMessageRequest)

GlobalUserAccount = _reflection.GeneratedProtocolMessageType('GlobalUserAccount', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALUSERACCOUNT,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GlobalUserAccount)
  })
_sym_db.RegisterMessage(GlobalUserAccount)

AccountUsername = _reflection.GeneratedProtocolMessageType('AccountUsername', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTUSERNAME,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AccountUsername)
  })
_sym_db.RegisterMessage(AccountUsername)

SsoServiceProviderRequest = _reflection.GeneratedProtocolMessageType('SsoServiceProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _SSOSERVICEPROVIDERREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SsoServiceProviderRequest)
  })
_sym_db.RegisterMessage(SsoServiceProviderRequest)

SsoServiceProviderResponse = _reflection.GeneratedProtocolMessageType('SsoServiceProviderResponse', (_message.Message,), {
  'DESCRIPTOR' : _SSOSERVICEPROVIDERRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SsoServiceProviderResponse)
  })
_sym_db.RegisterMessage(SsoServiceProviderResponse)

UserSettingRequest = _reflection.GeneratedProtocolMessageType('UserSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERSETTINGREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.UserSettingRequest)
  })
_sym_db.RegisterMessage(UserSettingRequest)

ThrottleState = _reflection.GeneratedProtocolMessageType('ThrottleState', (_message.Message,), {
  'DESCRIPTOR' : _THROTTLESTATE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ThrottleState)
  })
_sym_db.RegisterMessage(ThrottleState)

ThrottleState2 = _reflection.GeneratedProtocolMessageType('ThrottleState2', (_message.Message,), {
  'DESCRIPTOR' : _THROTTLESTATE2,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ThrottleState2)
  })
_sym_db.RegisterMessage(ThrottleState2)

DeviceInformation = _reflection.GeneratedProtocolMessageType('DeviceInformation', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEINFORMATION,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeviceInformation)
  })
_sym_db.RegisterMessage(DeviceInformation)

UserSetting = _reflection.GeneratedProtocolMessageType('UserSetting', (_message.Message,), {
  'DESCRIPTOR' : _USERSETTING,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.UserSetting)
  })
_sym_db.RegisterMessage(UserSetting)

UserDataKeyRequest = _reflection.GeneratedProtocolMessageType('UserDataKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERDATAKEYREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.UserDataKeyRequest)
  })
_sym_db.RegisterMessage(UserDataKeyRequest)

EnterpriseUserIdDataKeyPair = _reflection.GeneratedProtocolMessageType('EnterpriseUserIdDataKeyPair', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERIDDATAKEYPAIR,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.EnterpriseUserIdDataKeyPair)
  })
_sym_db.RegisterMessage(EnterpriseUserIdDataKeyPair)

UserDataKey = _reflection.GeneratedProtocolMessageType('UserDataKey', (_message.Message,), {
  'DESCRIPTOR' : _USERDATAKEY,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.UserDataKey)
  })
_sym_db.RegisterMessage(UserDataKey)

UserDataKeyResponse = _reflection.GeneratedProtocolMessageType('UserDataKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERDATAKEYRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.UserDataKeyResponse)
  })
_sym_db.RegisterMessage(UserDataKeyResponse)

MasterPasswordRecoveryVerificationRequest = _reflection.GeneratedProtocolMessageType('MasterPasswordRecoveryVerificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _MASTERPASSWORDRECOVERYVERIFICATIONREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.MasterPasswordRecoveryVerificationRequest)
  })
_sym_db.RegisterMessage(MasterPasswordRecoveryVerificationRequest)

GetSecurityQuestionV3Request = _reflection.GeneratedProtocolMessageType('GetSecurityQuestionV3Request', (_message.Message,), {
  'DESCRIPTOR' : _GETSECURITYQUESTIONV3REQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetSecurityQuestionV3Request)
  })
_sym_db.RegisterMessage(GetSecurityQuestionV3Request)

GetSecurityQuestionV3Response = _reflection.GeneratedProtocolMessageType('GetSecurityQuestionV3Response', (_message.Message,), {
  'DESCRIPTOR' : _GETSECURITYQUESTIONV3RESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetSecurityQuestionV3Response)
  })
_sym_db.RegisterMessage(GetSecurityQuestionV3Response)

GetDataKeyBackupV3Request = _reflection.GeneratedProtocolMessageType('GetDataKeyBackupV3Request', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAKEYBACKUPV3REQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetDataKeyBackupV3Request)
  })
_sym_db.RegisterMessage(GetDataKeyBackupV3Request)

PasswordRules = _reflection.GeneratedProtocolMessageType('PasswordRules', (_message.Message,), {
  'DESCRIPTOR' : _PASSWORDRULES,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.PasswordRules)
  })
_sym_db.RegisterMessage(PasswordRules)

GetDataKeyBackupV3Response = _reflection.GeneratedProtocolMessageType('GetDataKeyBackupV3Response', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAKEYBACKUPV3RESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetDataKeyBackupV3Response)
  })
_sym_db.RegisterMessage(GetDataKeyBackupV3Response)

GetPublicKeysRequest = _reflection.GeneratedProtocolMessageType('GetPublicKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICKEYSREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetPublicKeysRequest)
  })
_sym_db.RegisterMessage(GetPublicKeysRequest)

PublicKeyResponse = _reflection.GeneratedProtocolMessageType('PublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEYRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.PublicKeyResponse)
  })
_sym_db.RegisterMessage(PublicKeyResponse)

GetPublicKeysResponse = _reflection.GeneratedProtocolMessageType('GetPublicKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICKEYSRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetPublicKeysResponse)
  })
_sym_db.RegisterMessage(GetPublicKeysResponse)

SetEccKeyPairRequest = _reflection.GeneratedProtocolMessageType('SetEccKeyPairRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETECCKEYPAIRREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SetEccKeyPairRequest)
  })
_sym_db.RegisterMessage(SetEccKeyPairRequest)

AddAppSharesRequest = _reflection.GeneratedProtocolMessageType('AddAppSharesRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDAPPSHARESREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AddAppSharesRequest)
  })
_sym_db.RegisterMessage(AddAppSharesRequest)

RemoveAppSharesRequest = _reflection.GeneratedProtocolMessageType('RemoveAppSharesRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAPPSHARESREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RemoveAppSharesRequest)
  })
_sym_db.RegisterMessage(RemoveAppSharesRequest)

AppShareAdd = _reflection.GeneratedProtocolMessageType('AppShareAdd', (_message.Message,), {
  'DESCRIPTOR' : _APPSHAREADD,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AppShareAdd)
  })
_sym_db.RegisterMessage(AppShareAdd)

AppShare = _reflection.GeneratedProtocolMessageType('AppShare', (_message.Message,), {
  'DESCRIPTOR' : _APPSHARE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AppShare)
  })
_sym_db.RegisterMessage(AppShare)

AddAppClientRequest = _reflection.GeneratedProtocolMessageType('AddAppClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDAPPCLIENTREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AddAppClientRequest)
  })
_sym_db.RegisterMessage(AddAppClientRequest)

RemoveAppClientsRequest = _reflection.GeneratedProtocolMessageType('RemoveAppClientsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAPPCLIENTSREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RemoveAppClientsRequest)
  })
_sym_db.RegisterMessage(RemoveAppClientsRequest)

AddExternalShareRequest = _reflection.GeneratedProtocolMessageType('AddExternalShareRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDEXTERNALSHAREREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AddExternalShareRequest)
  })
_sym_db.RegisterMessage(AddExternalShareRequest)

AppClient = _reflection.GeneratedProtocolMessageType('AppClient', (_message.Message,), {
  'DESCRIPTOR' : _APPCLIENT,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AppClient)
  })
_sym_db.RegisterMessage(AppClient)

GetAppInfoRequest = _reflection.GeneratedProtocolMessageType('GetAppInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPINFOREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetAppInfoRequest)
  })
_sym_db.RegisterMessage(GetAppInfoRequest)

AppInfo = _reflection.GeneratedProtocolMessageType('AppInfo', (_message.Message,), {
  'DESCRIPTOR' : _APPINFO,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.AppInfo)
  })
_sym_db.RegisterMessage(AppInfo)

GetAppInfoResponse = _reflection.GeneratedProtocolMessageType('GetAppInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPINFORESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetAppInfoResponse)
  })
_sym_db.RegisterMessage(GetAppInfoResponse)

ApplicationSummary = _reflection.GeneratedProtocolMessageType('ApplicationSummary', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONSUMMARY,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.ApplicationSummary)
  })
_sym_db.RegisterMessage(ApplicationSummary)

GetApplicationsSummaryResponse = _reflection.GeneratedProtocolMessageType('GetApplicationsSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPLICATIONSSUMMARYRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetApplicationsSummaryResponse)
  })
_sym_db.RegisterMessage(GetApplicationsSummaryResponse)

GetVerificationTokenRequest = _reflection.GeneratedProtocolMessageType('GetVerificationTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVERIFICATIONTOKENREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetVerificationTokenRequest)
  })
_sym_db.RegisterMessage(GetVerificationTokenRequest)

GetVerificationTokenResponse = _reflection.GeneratedProtocolMessageType('GetVerificationTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVERIFICATIONTOKENRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.GetVerificationTokenResponse)
  })
_sym_db.RegisterMessage(GetVerificationTokenResponse)

SendShareInviteRequest = _reflection.GeneratedProtocolMessageType('SendShareInviteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDSHAREINVITEREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.SendShareInviteRequest)
  })
_sym_db.RegisterMessage(SendShareInviteRequest)

TimeLimitedAccessRequest = _reflection.GeneratedProtocolMessageType('TimeLimitedAccessRequest', (_message.Message,), {
  'DESCRIPTOR' : _TIMELIMITEDACCESSREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TimeLimitedAccessRequest)
  })
_sym_db.RegisterMessage(TimeLimitedAccessRequest)

TimeLimitedAccessResponse = _reflection.GeneratedProtocolMessageType('TimeLimitedAccessResponse', (_message.Message,), {
  'DESCRIPTOR' : _TIMELIMITEDACCESSRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.TimeLimitedAccessResponse)
  })
_sym_db.RegisterMessage(TimeLimitedAccessResponse)

RequestDownloadRequest = _reflection.GeneratedProtocolMessageType('RequestDownloadRequest', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDOWNLOADREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RequestDownloadRequest)
  })
_sym_db.RegisterMessage(RequestDownloadRequest)

RequestDownloadResponse = _reflection.GeneratedProtocolMessageType('RequestDownloadResponse', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDOWNLOADRESPONSE,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.RequestDownloadResponse)
  })
_sym_db.RegisterMessage(RequestDownloadResponse)

Download = _reflection.GeneratedProtocolMessageType('Download', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOAD,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.Download)
  })
_sym_db.RegisterMessage(Download)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQUEST,
  '__module__' : 'APIRequest_pb2'
  # @@protoc_insertion_point(class_scope:Authentication.DeleteUserRequest)
  })
_sym_db.RegisterMessage(DeleteUserRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.keepersecurity.protoB\016Authentication'
  _SUPPORTEDLANGUAGE._serialized_start=14963
  _SUPPORTEDLANGUAGE._serialized_end=15276
  _LOGINTYPE._serialized_start=15278
  _LOGINTYPE._serialized_end=15368
  _DEVICESTATUS._serialized_start=15370
  _DEVICESTATUS._serialized_end=15483
  _LICENSESTATUS._serialized_start=15485
  _LICENSESTATUS._serialized_end=15550
  _ACCOUNTTYPE._serialized_start=15552
  _ACCOUNTTYPE._serialized_end=15607
  _SESSIONTOKENTYPE._serialized_start=15610
  _SESSIONTOKENTYPE._serialized_end=15814
  _VERSION._serialized_start=15816
  _VERSION._serialized_end=15887
  _MASTERPASSWORDREENTRYACTIONTYPE._serialized_start=15889
  _MASTERPASSWORDREENTRYACTIONTYPE._serialized_end=15944
  _LOGINMETHOD._serialized_start=15946
  _LOGINMETHOD._serialized_end=16054
  _LOGINSTATE._serialized_start=16057
  _LOGINSTATE._serialized_end=16512
  _ENCRYPTEDDATAKEYTYPE._serialized_start=16514
  _ENCRYPTEDDATAKEYTYPE._serialized_end=16621
  _PASSWORDMETHOD._serialized_start=16623
  _PASSWORDMETHOD._serialized_end=16668
  _TWOFACTORPUSHTYPE._serialized_start=16671
  _TWOFACTORPUSHTYPE._serialized_end=16856
  _TWOFACTORVALUETYPE._serialized_start=16859
  _TWOFACTORVALUETYPE._serialized_end=17054
  _TWOFACTORCHANNELTYPE._serialized_start=17057
  _TWOFACTORCHANNELTYPE._serialized_end=17282
  _TWOFACTOREXPIRATION._serialized_start=17285
  _TWOFACTOREXPIRATION._serialized_end=17456
  _LICENSETYPE._serialized_start=17458
  _LICENSETYPE._serialized_end=17522
  _OBJECTTYPES._serialized_start=17524
  _OBJECTTYPES._serialized_end=17629
  _ALTERNATEAUTHENTICATIONTYPE._serialized_start=17631
  _ALTERNATEAUTHENTICATIONTYPE._serialized_end=17727
  _THROTTLETYPE._serialized_start=17730
  _THROTTLETYPE._serialized_end=18012
  _REGION._serialized_start=18014
  _REGION._serialized_end=18070
  _APPLICATIONSHARETYPE._serialized_start=18072
  _APPLICATIONSHARETYPE._serialized_end=18140
  _TIMELIMITEDACCESSTYPE._serialized_start=18143
  _TIMELIMITEDACCESSTYPE._serialized_end=18307
  _APIREQUEST._serialized_start=55
  _APIREQUEST._serialized_end=231
  _APIREQUESTPAYLOAD._serialized_start=233
  _APIREQUESTPAYLOAD._serialized_end=339
  _TRANSFORM._serialized_start=341
  _TRANSFORM._serialized_end=395
  _DEVICEREQUEST._serialized_start=397
  _DEVICEREQUEST._serialized_end=455
  _AUTHREQUEST._serialized_start=457
  _AUTHREQUEST._serialized_end=541
  _NEWUSERMINIMUMPARAMS._serialized_start=544
  _NEWUSERMINIMUMPARAMS._serialized_end=683
  _PRELOGINREQUEST._serialized_start=686
  _PRELOGINREQUEST._serialized_end=823
  _LOGINREQUEST._serialized_start=826
  _LOGINREQUEST._serialized_end=1082
  _DEVICERESPONSE._serialized_start=1084
  _DEVICERESPONSE._serialized_end=1176
  _SALT._serialized_start=1178
  _SALT._serialized_end=1264
  _TWOFACTORCHANNEL._serialized_start=1266
  _TWOFACTORCHANNEL._serialized_end=1298
  _STARTLOGINREQUEST._serialized_start=1301
  _STARTLOGINREQUEST._serialized_end=1655
  _LOGINRESPONSE._serialized_start=1658
  _LOGINRESPONSE._serialized_end=2175
  _SSOUSERINFO._serialized_start=2178
  _SSOUSERINFO._serialized_end=2318
  _PRELOGINRESPONSE._serialized_start=2321
  _PRELOGINRESPONSE._serialized_end=2535
  _LOGINASUSERREQUEST._serialized_start=2537
  _LOGINASUSERREQUEST._serialized_end=2575
  _LOGINASUSERRESPONSE._serialized_start=2577
  _LOGINASUSERRESPONSE._serialized_end=2664
  _VALIDATEAUTHHASHREQUEST._serialized_start=2667
  _VALIDATEAUTHHASHREQUEST._serialized_end=2799
  _TWOFACTORCHANNELINFO._serialized_start=2802
  _TWOFACTORCHANNELINFO._serialized_end=3066
  _TWOFACTORDUOSTATUS._serialized_start=3068
  _TWOFACTORDUOSTATUS._serialized_end=3168
  _TWOFACTORADDREQUEST._serialized_start=3171
  _TWOFACTORADDREQUEST._serialized_end=3370
  _TWOFACTORRENAMEREQUEST._serialized_start=3372
  _TWOFACTORRENAMEREQUEST._serialized_end=3438
  _TWOFACTORADDRESPONSE._serialized_start=3440
  _TWOFACTORADDRESPONSE._serialized_end=3501
  _TWOFACTORDELETEREQUEST._serialized_start=3503
  _TWOFACTORDELETEREQUEST._serialized_end=3548
  _TWOFACTORLISTRESPONSE._serialized_start=3550
  _TWOFACTORLISTRESPONSE._serialized_end=3647
  _TWOFACTORUPDATEEXPIRATIONREQUEST._serialized_start=3649
  _TWOFACTORUPDATEEXPIRATIONREQUEST._serialized_end=3738
  _TWOFACTORVALIDATEREQUEST._serialized_start=3741
  _TWOFACTORVALIDATEREQUEST._serialized_end=3942
  _TWOFACTORVALIDATERESPONSE._serialized_start=3944
  _TWOFACTORVALIDATERESPONSE._serialized_end=4000
  _TWOFACTORSENDPUSHREQUEST._serialized_start=4003
  _TWOFACTORSENDPUSHREQUEST._serialized_end=4187
  _LICENSE._serialized_start=4190
  _LICENSE._serialized_end=4321
  _OWNERLESSRECORD._serialized_start=4323
  _OWNERLESSRECORD._serialized_end=4394
  _OWNERLESSRECORDS._serialized_start=4396
  _OWNERLESSRECORDS._serialized_end=4472
  _USERAUTHREQUEST._serialized_start=4475
  _USERAUTHREQUEST._serialized_end=4690
  _UIDREQUEST._serialized_start=4692
  _UIDREQUEST._serialized_end=4717
  _DEVICEUPDATEREQUEST._serialized_start=4720
  _DEVICEUPDATEREQUEST._serialized_end=4891
  _REGISTERDEVICEINREGIONREQUEST._serialized_start=4894
  _REGISTERDEVICEINREGIONREQUEST._serialized_end=5023
  _REGISTRATIONREQUEST._serialized_start=5026
  _REGISTRATIONREQUEST._serialized_end=5402
  _CONVERTUSERTOV3REQUEST._serialized_start=5405
  _CONVERTUSERTOV3REQUEST._serialized_end=5613
  _REVISIONRESPONSE._serialized_start=5615
  _REVISIONRESPONSE._serialized_end=5651
  _CHANGEEMAILREQUEST._serialized_start=5653
  _CHANGEEMAILREQUEST._serialized_end=5691
  _CHANGEEMAILRESPONSE._serialized_start=5693
  _CHANGEEMAILRESPONSE._serialized_end=5749
  _EMAILVERIFICATIONLINKRESPONSE._serialized_start=5751
  _EMAILVERIFICATIONLINKRESPONSE._serialized_end=5805
  _SECURITYDATA._serialized_start=5807
  _SECURITYDATA._serialized_end=5848
  _SECURITYDATAREQUEST._serialized_start=5851
  _SECURITYDATAREQUEST._serialized_end=5996
  _SECURITYREPORTINCREMENTALDATA._serialized_start=5999
  _SECURITYREPORTINCREMENTALDATA._serialized_end=6180
  _SECURITYREPORT._serialized_start=6183
  _SECURITYREPORT._serialized_end=6444
  _SECURITYREPORTSAVEREQUEST._serialized_start=6446
  _SECURITYREPORTSAVEREQUEST._serialized_end=6529
  _SECURITYREPORTREQUEST._serialized_start=6531
  _SECURITYREPORTREQUEST._serialized_end=6572
  _SECURITYREPORTRESPONSE._serialized_start=6575
  _SECURITYREPORTRESPONSE._serialized_end=6759
  _REUSEDPASSWORDSREQUEST._serialized_start=6761
  _REUSEDPASSWORDSREQUEST._serialized_end=6800
  _SUMMARYCONSOLEREPORT._serialized_start=6802
  _SUMMARYCONSOLEREPORT._serialized_end=6864
  _CHANGETOKEYTYPEONE._serialized_start=6866
  _CHANGETOKEYTYPEONE._serialized_end=6990
  _CHANGETOKEYTYPEONEREQUEST._serialized_start=6992
  _CHANGETOKEYTYPEONEREQUEST._serialized_end=7083
  _CHANGETOKEYTYPEONESTATUS._serialized_start=7085
  _CHANGETOKEYTYPEONESTATUS._serialized_end=7170
  _CHANGETOKEYTYPEONERESPONSE._serialized_start=7172
  _CHANGETOKEYTYPEONERESPONSE._serialized_end=7276
  _SETKEY._serialized_start=7278
  _SETKEY._serialized_end=7311
  _SETKEYREQUEST._serialized_start=7313
  _SETKEYREQUEST._serialized_end=7366
  _CREATEUSERREQUEST._serialized_start=7369
  _CREATEUSERREQUEST._serialized_end=7995
  _NODEENFORCEMENTADDORUPDATEREQUEST._serialized_start=7997
  _NODEENFORCEMENTADDORUPDATEREQUEST._serialized_end=8084
  _NODEENFORCEMENTREMOVEREQUEST._serialized_start=8086
  _NODEENFORCEMENTREMOVEREQUEST._serialized_end=8153
  _APIREQUESTBYKEY._serialized_start=8156
  _APIREQUESTBYKEY._serialized_end=8315
  _APIREQUESTBYKATOKAKEY._serialized_start=8318
  _APIREQUESTBYKATOKAKEY._serialized_end=8588
  _MEMCACHEREQUEST._serialized_start=8590
  _MEMCACHEREQUEST._serialized_end=8636
  _MEMCACHERESPONSE._serialized_start=8638
  _MEMCACHERESPONSE._serialized_end=8684
  _MASTERPASSWORDREENTRYREQUEST._serialized_start=8686
  _MASTERPASSWORDREENTRYREQUEST._serialized_end=8805
  _DEVICEREGISTRATIONREQUEST._serialized_start=8807
  _DEVICEREGISTRATIONREQUEST._serialized_end=8902
  _DEVICEVERIFICATIONREQUEST._serialized_start=8905
  _DEVICEVERIFICATIONREQUEST._serialized_end=9059
  _DEVICEVERIFICATIONRESPONSE._serialized_start=9062
  _DEVICEVERIFICATIONRESPONSE._serialized_end=9240
  _DEVICEAPPROVALREQUEST._serialized_start=9243
  _DEVICEAPPROVALREQUEST._serialized_end=9443
  _DEVICEAPPROVALRESPONSE._serialized_start=9445
  _DEVICEAPPROVALRESPONSE._serialized_end=9502
  _APPROVEDEVICEREQUEST._serialized_start=9504
  _APPROVEDEVICEREQUEST._serialized_end=9630
  _ENTERPRISEUSERALIASREQUEST._serialized_start=9632
  _ENTERPRISEUSERALIASREQUEST._serialized_end=9701
  _ENTERPRISEUSERADDALIASREQUEST._serialized_start=9703
  _ENTERPRISEUSERADDALIASREQUEST._serialized_end=9792
  _DEVICE._serialized_start=9794
  _DEVICE._serialized_end=9832
  _REGISTERDEVICEDATAKEYREQUEST._serialized_start=9834
  _REGISTERDEVICEDATAKEYREQUEST._serialized_end=9926
  _VALIDATECREATEUSERVERIFICATIONCODEREQUEST._serialized_start=9928
  _VALIDATECREATEUSERVERIFICATIONCODEREQUEST._serialized_end=10038
  _VALIDATEDEVICEVERIFICATIONCODEREQUEST._serialized_start=10041
  _VALIDATEDEVICEVERIFICATIONCODEREQUEST._serialized_end=10204
  _SENDSESSIONMESSAGEREQUEST._serialized_start=10206
  _SENDSESSIONMESSAGEREQUEST._serialized_end=10295
  _GLOBALUSERACCOUNT._serialized_start=10297
  _GLOBALUSERACCOUNT._serialized_end=10374
  _ACCOUNTUSERNAME._serialized_start=10376
  _ACCOUNTUSERNAME._serialized_end=10431
  _SSOSERVICEPROVIDERREQUEST._serialized_start=10433
  _SSOSERVICEPROVIDERREQUEST._serialized_end=10513
  _SSOSERVICEPROVIDERRESPONSE._serialized_start=10515
  _SSOSERVICEPROVIDERRESPONSE._serialized_end=10612
  _USERSETTINGREQUEST._serialized_start=10614
  _USERSETTINGREQUEST._serialized_end=10666
  _THROTTLESTATE._serialized_start=10668
  _THROTTLESTATE._serialized_end=10770
  _THROTTLESTATE2._serialized_start=10773
  _THROTTLESTATE2._serialized_end=10954
  _DEVICEINFORMATION._serialized_start=10957
  _DEVICEINFORMATION._serialized_end=11108
  _USERSETTING._serialized_start=11110
  _USERSETTING._serialized_end=11152
  _USERDATAKEYREQUEST._serialized_start=11154
  _USERDATAKEYREQUEST._serialized_end=11200
  _ENTERPRISEUSERIDDATAKEYPAIR._serialized_start=11202
  _ENTERPRISEUSERIDDATAKEYPAIR._serialized_end=11283
  _USERDATAKEY._serialized_start=11286
  _USERDATAKEY._serialized_end=11435
  _USERDATAKEYRESPONSE._serialized_start=11437
  _USERDATAKEYRESPONSE._serialized_end=11559
  _MASTERPASSWORDRECOVERYVERIFICATIONREQUEST._serialized_start=11561
  _MASTERPASSWORDRECOVERYVERIFICATIONREQUEST._serialized_end=11633
  _GETSECURITYQUESTIONV3REQUEST._serialized_start=11635
  _GETSECURITYQUESTIONV3REQUEST._serialized_end=11720
  _GETSECURITYQUESTIONV3RESPONSE._serialized_start=11722
  _GETSECURITYQUESTIONV3RESPONSE._serialized_end=11836
  _GETDATAKEYBACKUPV3REQUEST._serialized_start=11838
  _GETDATAKEYBACKUPV3REQUEST._serialized_end=11948
  _PASSWORDRULES._serialized_start=11950
  _PASSWORDRULES._serialized_end=12068
  _GETDATAKEYBACKUPV3RESPONSE._serialized_start=12071
  _GETDATAKEYBACKUPV3RESPONSE._serialized_end=12362
  _GETPUBLICKEYSREQUEST._serialized_start=12364
  _GETPUBLICKEYSREQUEST._serialized_end=12405
  _PUBLICKEYRESPONSE._serialized_start=12407
  _PUBLICKEYRESPONSE._serialized_end=12521
  _GETPUBLICKEYSRESPONSE._serialized_start=12523
  _GETPUBLICKEYSRESPONSE._serialized_end=12603
  _SETECCKEYPAIRREQUEST._serialized_start=12605
  _SETECCKEYPAIRREQUEST._serialized_end=12675
  _ADDAPPSHARESREQUEST._serialized_start=12677
  _ADDAPPSHARESREQUEST._serialized_end=12765
  _REMOVEAPPSHARESREQUEST._serialized_start=12767
  _REMOVEAPPSHARESREQUEST._serialized_end=12829
  _APPSHAREADD._serialized_start=12832
  _APPSHAREADD._serialized_end=12967
  _APPSHARE._serialized_start=12969
  _APPSHARE._serialized_end=13092
  _ADDAPPCLIENTREQUEST._serialized_start=13095
  _ADDAPPCLIENTREQUEST._serialized_end=13312
  _REMOVEAPPCLIENTSREQUEST._serialized_start=13314
  _REMOVEAPPCLIENTSREQUEST._serialized_end=13378
  _ADDEXTERNALSHAREREQUEST._serialized_start=13380
  _ADDEXTERNALSHAREREQUEST._serialized_end=13506
  _APPCLIENT._serialized_start=13509
  _APPCLIENT._serialized_end=13767
  _GETAPPINFOREQUEST._serialized_start=13769
  _GETAPPINFOREQUEST._serialized_end=13810
  _APPINFO._serialized_start=13813
  _APPINFO._serialized_end=13955
  _GETAPPINFORESPONSE._serialized_start=13957
  _GETAPPINFORESPONSE._serialized_end=14019
  _APPLICATIONSUMMARY._serialized_start=14022
  _APPLICATIONSUMMARY._serialized_end=14200
  _GETAPPLICATIONSSUMMARYRESPONSE._serialized_start=14202
  _GETAPPLICATIONSSUMMARYRESPONSE._serialized_end=14298
  _GETVERIFICATIONTOKENREQUEST._serialized_start=14300
  _GETVERIFICATIONTOKENREQUEST._serialized_end=14347
  _GETVERIFICATIONTOKENRESPONSE._serialized_start=14349
  _GETVERIFICATIONTOKENRESPONSE._serialized_end=14415
  _SENDSHAREINVITEREQUEST._serialized_start=14417
  _SENDSHAREINVITEREQUEST._serialized_end=14456
  _TIMELIMITEDACCESSREQUEST._serialized_start=14459
  _TIMELIMITEDACCESSREQUEST._serialized_end=14656
  _TIMELIMITEDACCESSRESPONSE._serialized_start=14658
  _TIMELIMITEDACCESSRESPONSE._serialized_end=14703
  _REQUESTDOWNLOADREQUEST._serialized_start=14705
  _REQUESTDOWNLOADREQUEST._serialized_end=14748
  _REQUESTDOWNLOADRESPONSE._serialized_start=14750
  _REQUESTDOWNLOADRESPONSE._serialized_end=14853
  _DOWNLOAD._serialized_start=14855
  _DOWNLOAD._serialized_end=14923
  _DELETEUSERREQUEST._serialized_start=14925
  _DELETEUSERREQUEST._serialized_end=14960
# @@protoc_insertion_point(module_scope)
